# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .format_entry import FormatEntry
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RandomListFormatEntry(FormatEntry):
    """
    The Random List masking format randomly selects values from a list of values
    to replace the original values. To learn more, check Random List in the
    Data Safe documentation.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RandomListFormatEntry object with values from keyword arguments. The default value of the :py:attr:`~oci.data_safe.models.RandomListFormatEntry.type` attribute
        of this class is ``RANDOM_LIST`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this RandomListFormatEntry.
            Allowed values for this property are: "DELETE_ROWS", "DETERMINISTIC_SUBSTITUTION", "DETERMINISTIC_ENCRYPTION", "DETERMINISTIC_ENCRYPTION_DATE", "FIXED_NUMBER", "FIXED_STRING", "LIBRARY_MASKING_FORMAT", "NULL_VALUE", "POST_PROCESSING_FUNCTION", "PRESERVE_ORIGINAL_DATA", "RANDOM_DATE", "RANDOM_DECIMAL_NUMBER", "RANDOM_DIGITS", "RANDOM_LIST", "RANDOM_NUMBER", "RANDOM_STRING", "RANDOM_SUBSTITUTION", "REGULAR_EXPRESSION", "SHUFFLE", "SQL_EXPRESSION", "SUBSTRING", "TRUNCATE_TABLE", "USER_DEFINED_FUNCTION"
        :type type: str

        :param description:
            The value to assign to the description property of this RandomListFormatEntry.
        :type description: str

        :param random_list:
            The value to assign to the random_list property of this RandomListFormatEntry.
        :type random_list: list[str]

        """
        self.swagger_types = {
            'type': 'str',
            'description': 'str',
            'random_list': 'list[str]'
        }

        self.attribute_map = {
            'type': 'type',
            'description': 'description',
            'random_list': 'randomList'
        }

        self._type = None
        self._description = None
        self._random_list = None
        self._type = 'RANDOM_LIST'

    @property
    def random_list(self):
        """
        **[Required]** Gets the random_list of this RandomListFormatEntry.
        A comma-separated list of values to be used to replace column values.
        The list can be of strings, numbers, or dates. The data type of each
        value in the list must be compatible with the data type of the column.
        The number of entries in the list cannot be more than 999.


        :return: The random_list of this RandomListFormatEntry.
        :rtype: list[str]
        """
        return self._random_list

    @random_list.setter
    def random_list(self, random_list):
        """
        Sets the random_list of this RandomListFormatEntry.
        A comma-separated list of values to be used to replace column values.
        The list can be of strings, numbers, or dates. The data type of each
        value in the list must be compatible with the data type of the column.
        The number of entries in the list cannot be more than 999.


        :param random_list: The random_list of this RandomListFormatEntry.
        :type: list[str]
        """
        self._random_list = random_list

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VulnerabilityAuditSummary(object):
    """
    Summary of vulnerability audit.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new VulnerabilityAuditSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param vulnerability_audit_id:
            The value to assign to the vulnerability_audit_id property of this VulnerabilityAuditSummary.
        :type vulnerability_audit_id: str

        :param commit_hash:
            The value to assign to the commit_hash property of this VulnerabilityAuditSummary.
        :type commit_hash: str

        :param build_stage_id:
            The value to assign to the build_stage_id property of this VulnerabilityAuditSummary.
        :type build_stage_id: str

        """
        self.swagger_types = {
            'vulnerability_audit_id': 'str',
            'commit_hash': 'str',
            'build_stage_id': 'str'
        }

        self.attribute_map = {
            'vulnerability_audit_id': 'vulnerabilityAuditId',
            'commit_hash': 'commitHash',
            'build_stage_id': 'buildStageId'
        }

        self._vulnerability_audit_id = None
        self._commit_hash = None
        self._build_stage_id = None

    @property
    def vulnerability_audit_id(self):
        """
        **[Required]** Gets the vulnerability_audit_id of this VulnerabilityAuditSummary.
        The OCID of the vulnerability audit.


        :return: The vulnerability_audit_id of this VulnerabilityAuditSummary.
        :rtype: str
        """
        return self._vulnerability_audit_id

    @vulnerability_audit_id.setter
    def vulnerability_audit_id(self, vulnerability_audit_id):
        """
        Sets the vulnerability_audit_id of this VulnerabilityAuditSummary.
        The OCID of the vulnerability audit.


        :param vulnerability_audit_id: The vulnerability_audit_id of this VulnerabilityAuditSummary.
        :type: str
        """
        self._vulnerability_audit_id = vulnerability_audit_id

    @property
    def commit_hash(self):
        """
        Gets the commit_hash of this VulnerabilityAuditSummary.
        Commit hash used while retrieving the pom file for vulnerabilityAudit.


        :return: The commit_hash of this VulnerabilityAuditSummary.
        :rtype: str
        """
        return self._commit_hash

    @commit_hash.setter
    def commit_hash(self, commit_hash):
        """
        Sets the commit_hash of this VulnerabilityAuditSummary.
        Commit hash used while retrieving the pom file for vulnerabilityAudit.


        :param commit_hash: The commit_hash of this VulnerabilityAuditSummary.
        :type: str
        """
        self._commit_hash = commit_hash

    @property
    def build_stage_id(self):
        """
        **[Required]** Gets the build_stage_id of this VulnerabilityAuditSummary.
        Build stage OCID where scan was configured.


        :return: The build_stage_id of this VulnerabilityAuditSummary.
        :rtype: str
        """
        return self._build_stage_id

    @build_stage_id.setter
    def build_stage_id(self, build_stage_id):
        """
        Sets the build_stage_id of this VulnerabilityAuditSummary.
        Build stage OCID where scan was configured.


        :param build_stage_id: The build_stage_id of this VulnerabilityAuditSummary.
        :type: str
        """
        self._build_stage_id = build_stage_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BlockVolumeReplicaInfo(object):
    """
    Information about the block volume replica in the destination availability domain.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new BlockVolumeReplicaInfo object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this BlockVolumeReplicaInfo.
        :type display_name: str

        :param block_volume_replica_id:
            The value to assign to the block_volume_replica_id property of this BlockVolumeReplicaInfo.
        :type block_volume_replica_id: str

        :param availability_domain:
            The value to assign to the availability_domain property of this BlockVolumeReplicaInfo.
        :type availability_domain: str

        """
        self.swagger_types = {
            'display_name': 'str',
            'block_volume_replica_id': 'str',
            'availability_domain': 'str'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'block_volume_replica_id': 'blockVolumeReplicaId',
            'availability_domain': 'availabilityDomain'
        }

        self._display_name = None
        self._block_volume_replica_id = None
        self._availability_domain = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this BlockVolumeReplicaInfo.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this BlockVolumeReplicaInfo.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this BlockVolumeReplicaInfo.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this BlockVolumeReplicaInfo.
        :type: str
        """
        self._display_name = display_name

    @property
    def block_volume_replica_id(self):
        """
        **[Required]** Gets the block_volume_replica_id of this BlockVolumeReplicaInfo.
        The block volume replica's Oracle ID (OCID).


        :return: The block_volume_replica_id of this BlockVolumeReplicaInfo.
        :rtype: str
        """
        return self._block_volume_replica_id

    @block_volume_replica_id.setter
    def block_volume_replica_id(self, block_volume_replica_id):
        """
        Sets the block_volume_replica_id of this BlockVolumeReplicaInfo.
        The block volume replica's Oracle ID (OCID).


        :param block_volume_replica_id: The block_volume_replica_id of this BlockVolumeReplicaInfo.
        :type: str
        """
        self._block_volume_replica_id = block_volume_replica_id

    @property
    def availability_domain(self):
        """
        **[Required]** Gets the availability_domain of this BlockVolumeReplicaInfo.
        The availability domain of the block volume replica.

        Example: `Uocm:PHX-AD-1`


        :return: The availability_domain of this BlockVolumeReplicaInfo.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this BlockVolumeReplicaInfo.
        The availability domain of the block volume replica.

        Example: `Uocm:PHX-AD-1`


        :param availability_domain: The availability_domain of this BlockVolumeReplicaInfo.
        :type: str
        """
        self._availability_domain = availability_domain

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class WorkRequestSummary(object):
    """
    Summary of a work request.
    """

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "ENABLE_DATA_SAFE_CONFIGURATION"
    OPERATION_TYPE_ENABLE_DATA_SAFE_CONFIGURATION = "ENABLE_DATA_SAFE_CONFIGURATION"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CREATE_PRIVATE_ENDPOINT"
    OPERATION_TYPE_CREATE_PRIVATE_ENDPOINT = "CREATE_PRIVATE_ENDPOINT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "UPDATE_PRIVATE_ENDPOINT"
    OPERATION_TYPE_UPDATE_PRIVATE_ENDPOINT = "UPDATE_PRIVATE_ENDPOINT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "DELETE_PRIVATE_ENDPOINT"
    OPERATION_TYPE_DELETE_PRIVATE_ENDPOINT = "DELETE_PRIVATE_ENDPOINT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CHANGE_PRIVATE_ENDPOINT_COMPARTMENT"
    OPERATION_TYPE_CHANGE_PRIVATE_ENDPOINT_COMPARTMENT = "CHANGE_PRIVATE_ENDPOINT_COMPARTMENT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CREATE_ONPREM_CONNECTOR"
    OPERATION_TYPE_CREATE_ONPREM_CONNECTOR = "CREATE_ONPREM_CONNECTOR"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "UPDATE_ONPREM_CONNECTOR"
    OPERATION_TYPE_UPDATE_ONPREM_CONNECTOR = "UPDATE_ONPREM_CONNECTOR"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "DELETE_ONPREM_CONNECTOR"
    OPERATION_TYPE_DELETE_ONPREM_CONNECTOR = "DELETE_ONPREM_CONNECTOR"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "UPDATE_ONPREM_CONNECTOR_WALLET"
    OPERATION_TYPE_UPDATE_ONPREM_CONNECTOR_WALLET = "UPDATE_ONPREM_CONNECTOR_WALLET"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CHANGE_ONPREM_CONNECTOR_COMPARTMENT"
    OPERATION_TYPE_CHANGE_ONPREM_CONNECTOR_COMPARTMENT = "CHANGE_ONPREM_CONNECTOR_COMPARTMENT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "PROVISION_POLICY"
    OPERATION_TYPE_PROVISION_POLICY = "PROVISION_POLICY"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "RETRIEVE_POLICY"
    OPERATION_TYPE_RETRIEVE_POLICY = "RETRIEVE_POLICY"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "UPDATE_POLICY"
    OPERATION_TYPE_UPDATE_POLICY = "UPDATE_POLICY"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CHANGE_POLICY_COMPARTMENT"
    OPERATION_TYPE_CHANGE_POLICY_COMPARTMENT = "CHANGE_POLICY_COMPARTMENT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CREATE_TARGET_DATABASE"
    OPERATION_TYPE_CREATE_TARGET_DATABASE = "CREATE_TARGET_DATABASE"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "UPDATE_TARGET_DATABASE"
    OPERATION_TYPE_UPDATE_TARGET_DATABASE = "UPDATE_TARGET_DATABASE"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "ACTIVATE_TARGET_DATABASE"
    OPERATION_TYPE_ACTIVATE_TARGET_DATABASE = "ACTIVATE_TARGET_DATABASE"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "DEACTIVATE_TARGET_DATABASE"
    OPERATION_TYPE_DEACTIVATE_TARGET_DATABASE = "DEACTIVATE_TARGET_DATABASE"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "DELETE_TARGET_DATABASE"
    OPERATION_TYPE_DELETE_TARGET_DATABASE = "DELETE_TARGET_DATABASE"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CHANGE_TARGET_DATABASE_COMPARTMENT"
    OPERATION_TYPE_CHANGE_TARGET_DATABASE_COMPARTMENT = "CHANGE_TARGET_DATABASE_COMPARTMENT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CREATE_USER_ASSESSMENT"
    OPERATION_TYPE_CREATE_USER_ASSESSMENT = "CREATE_USER_ASSESSMENT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "ASSESS_USER_ASSESSMENT"
    OPERATION_TYPE_ASSESS_USER_ASSESSMENT = "ASSESS_USER_ASSESSMENT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CREATE_SNAPSHOT_USER_ASSESSMENT"
    OPERATION_TYPE_CREATE_SNAPSHOT_USER_ASSESSMENT = "CREATE_SNAPSHOT_USER_ASSESSMENT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CREATE_SCHEDULE_USER_ASSESSMENT"
    OPERATION_TYPE_CREATE_SCHEDULE_USER_ASSESSMENT = "CREATE_SCHEDULE_USER_ASSESSMENT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "COMPARE_WITH_BASELINE_USER_ASSESSMENT"
    OPERATION_TYPE_COMPARE_WITH_BASELINE_USER_ASSESSMENT = "COMPARE_WITH_BASELINE_USER_ASSESSMENT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "DELETE_USER_ASSESSMENT"
    OPERATION_TYPE_DELETE_USER_ASSESSMENT = "DELETE_USER_ASSESSMENT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "UPDATE_USER_ASSESSMENT"
    OPERATION_TYPE_UPDATE_USER_ASSESSMENT = "UPDATE_USER_ASSESSMENT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CHANGE_USER_ASSESSMENT_COMPARTMENT"
    OPERATION_TYPE_CHANGE_USER_ASSESSMENT_COMPARTMENT = "CHANGE_USER_ASSESSMENT_COMPARTMENT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "SET_USER_ASSESSMENT_BASELINE"
    OPERATION_TYPE_SET_USER_ASSESSMENT_BASELINE = "SET_USER_ASSESSMENT_BASELINE"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "UNSET_USER_ASSESSMENT_BASELINE"
    OPERATION_TYPE_UNSET_USER_ASSESSMENT_BASELINE = "UNSET_USER_ASSESSMENT_BASELINE"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "GENERATE_USER_ASSESSMENT_REPORT"
    OPERATION_TYPE_GENERATE_USER_ASSESSMENT_REPORT = "GENERATE_USER_ASSESSMENT_REPORT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CREATE_SECURITY_ASSESSMENT"
    OPERATION_TYPE_CREATE_SECURITY_ASSESSMENT = "CREATE_SECURITY_ASSESSMENT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CREATE_SECURITY_ASSESSMENT_NOW"
    OPERATION_TYPE_CREATE_SECURITY_ASSESSMENT_NOW = "CREATE_SECURITY_ASSESSMENT_NOW"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "ASSESS_SECURITY_ASSESSMENT"
    OPERATION_TYPE_ASSESS_SECURITY_ASSESSMENT = "ASSESS_SECURITY_ASSESSMENT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CREATE_SNAPSHOT_SECURITY_ASSESSMENT"
    OPERATION_TYPE_CREATE_SNAPSHOT_SECURITY_ASSESSMENT = "CREATE_SNAPSHOT_SECURITY_ASSESSMENT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CREATE_SCHEDULE_SECURITY_ASSESSMENT"
    OPERATION_TYPE_CREATE_SCHEDULE_SECURITY_ASSESSMENT = "CREATE_SCHEDULE_SECURITY_ASSESSMENT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "COMPARE_WITH_BASELINE_SECURITY_ASSESSMENT"
    OPERATION_TYPE_COMPARE_WITH_BASELINE_SECURITY_ASSESSMENT = "COMPARE_WITH_BASELINE_SECURITY_ASSESSMENT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "DELETE_SECURITY_ASSESSMENT"
    OPERATION_TYPE_DELETE_SECURITY_ASSESSMENT = "DELETE_SECURITY_ASSESSMENT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "UPDATE_SECURITY_ASSESSMENT"
    OPERATION_TYPE_UPDATE_SECURITY_ASSESSMENT = "UPDATE_SECURITY_ASSESSMENT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CHANGE_SECURITY_ASSESSMENT_COMPARTMENT"
    OPERATION_TYPE_CHANGE_SECURITY_ASSESSMENT_COMPARTMENT = "CHANGE_SECURITY_ASSESSMENT_COMPARTMENT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "SET_SECURITY_ASSESSMENT_BASELINE"
    OPERATION_TYPE_SET_SECURITY_ASSESSMENT_BASELINE = "SET_SECURITY_ASSESSMENT_BASELINE"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "UNSET_SECURITY_ASSESSMENT_BASELINE"
    OPERATION_TYPE_UNSET_SECURITY_ASSESSMENT_BASELINE = "UNSET_SECURITY_ASSESSMENT_BASELINE"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "GENERATE_SECURITY_ASSESSMENT_REPORT"
    OPERATION_TYPE_GENERATE_SECURITY_ASSESSMENT_REPORT = "GENERATE_SECURITY_ASSESSMENT_REPORT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CALCULATE_VOLUME"
    OPERATION_TYPE_CALCULATE_VOLUME = "CALCULATE_VOLUME"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CALCULATE_COLLECTED_VOLUME"
    OPERATION_TYPE_CALCULATE_COLLECTED_VOLUME = "CALCULATE_COLLECTED_VOLUME"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "AUDIT_TRAIL"
    OPERATION_TYPE_AUDIT_TRAIL = "AUDIT_TRAIL"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "DELETE_AUDIT_TRAIL"
    OPERATION_TYPE_DELETE_AUDIT_TRAIL = "DELETE_AUDIT_TRAIL"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "DISCOVER_AUDIT_TRAILS"
    OPERATION_TYPE_DISCOVER_AUDIT_TRAILS = "DISCOVER_AUDIT_TRAILS"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "UPDATE_AUDIT_TRAIL"
    OPERATION_TYPE_UPDATE_AUDIT_TRAIL = "UPDATE_AUDIT_TRAIL"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "UPDATE_AUDIT_PROFILE"
    OPERATION_TYPE_UPDATE_AUDIT_PROFILE = "UPDATE_AUDIT_PROFILE"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "AUDIT_CHANGE_COMPARTMENT"
    OPERATION_TYPE_AUDIT_CHANGE_COMPARTMENT = "AUDIT_CHANGE_COMPARTMENT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CREATE_REPORT_DEFINITION"
    OPERATION_TYPE_CREATE_REPORT_DEFINITION = "CREATE_REPORT_DEFINITION"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "UPDATE_REPORT_DEFINITION"
    OPERATION_TYPE_UPDATE_REPORT_DEFINITION = "UPDATE_REPORT_DEFINITION"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CHANGE_REPORT_DEFINITION_COMPARTMENT"
    OPERATION_TYPE_CHANGE_REPORT_DEFINITION_COMPARTMENT = "CHANGE_REPORT_DEFINITION_COMPARTMENT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "DELETE_REPORT_DEFINITION"
    OPERATION_TYPE_DELETE_REPORT_DEFINITION = "DELETE_REPORT_DEFINITION"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "GENERATE_REPORT"
    OPERATION_TYPE_GENERATE_REPORT = "GENERATE_REPORT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CHANGE_REPORT_COMPARTMENT"
    OPERATION_TYPE_CHANGE_REPORT_COMPARTMENT = "CHANGE_REPORT_COMPARTMENT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "DELETE_ARCHIVE_RETRIEVAL"
    OPERATION_TYPE_DELETE_ARCHIVE_RETRIEVAL = "DELETE_ARCHIVE_RETRIEVAL"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CREATE_ARCHIVE_RETRIEVAL"
    OPERATION_TYPE_CREATE_ARCHIVE_RETRIEVAL = "CREATE_ARCHIVE_RETRIEVAL"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "UPDATE_ARCHIVE_RETRIEVAL"
    OPERATION_TYPE_UPDATE_ARCHIVE_RETRIEVAL = "UPDATE_ARCHIVE_RETRIEVAL"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CHANGE_ARCHIVE_RETRIEVAL_COMPARTMENT"
    OPERATION_TYPE_CHANGE_ARCHIVE_RETRIEVAL_COMPARTMENT = "CHANGE_ARCHIVE_RETRIEVAL_COMPARTMENT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "UPDATE_ALERT"
    OPERATION_TYPE_UPDATE_ALERT = "UPDATE_ALERT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "TARGET_ALERT_POLICY_ASSOCIATION"
    OPERATION_TYPE_TARGET_ALERT_POLICY_ASSOCIATION = "TARGET_ALERT_POLICY_ASSOCIATION"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CREATE_SENSITIVE_DATA_MODEL"
    OPERATION_TYPE_CREATE_SENSITIVE_DATA_MODEL = "CREATE_SENSITIVE_DATA_MODEL"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "UPDATE_SENSITIVE_DATA_MODEL"
    OPERATION_TYPE_UPDATE_SENSITIVE_DATA_MODEL = "UPDATE_SENSITIVE_DATA_MODEL"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "DELETE_SENSITIVE_DATA_MODEL"
    OPERATION_TYPE_DELETE_SENSITIVE_DATA_MODEL = "DELETE_SENSITIVE_DATA_MODEL"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "UPLOAD_SENSITIVE_DATA_MODEL"
    OPERATION_TYPE_UPLOAD_SENSITIVE_DATA_MODEL = "UPLOAD_SENSITIVE_DATA_MODEL"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "GENERATE_SENSITIVE_DATA_MODEL_FOR_DOWNLOAD"
    OPERATION_TYPE_GENERATE_SENSITIVE_DATA_MODEL_FOR_DOWNLOAD = "GENERATE_SENSITIVE_DATA_MODEL_FOR_DOWNLOAD"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CREATE_SENSITIVE_COLUMN"
    OPERATION_TYPE_CREATE_SENSITIVE_COLUMN = "CREATE_SENSITIVE_COLUMN"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "UPDATE_SENSITIVE_COLUMN"
    OPERATION_TYPE_UPDATE_SENSITIVE_COLUMN = "UPDATE_SENSITIVE_COLUMN"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "PATCH_SENSITIVE_COLUMNS"
    OPERATION_TYPE_PATCH_SENSITIVE_COLUMNS = "PATCH_SENSITIVE_COLUMNS"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CREATE_DISCOVERY_JOB"
    OPERATION_TYPE_CREATE_DISCOVERY_JOB = "CREATE_DISCOVERY_JOB"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "DELETE_DISCOVERY_JOB"
    OPERATION_TYPE_DELETE_DISCOVERY_JOB = "DELETE_DISCOVERY_JOB"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "PATCH_DISCOVERY_JOB_RESULT"
    OPERATION_TYPE_PATCH_DISCOVERY_JOB_RESULT = "PATCH_DISCOVERY_JOB_RESULT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "APPLY_DISCOVERY_JOB_RESULT"
    OPERATION_TYPE_APPLY_DISCOVERY_JOB_RESULT = "APPLY_DISCOVERY_JOB_RESULT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "GENERATE_DISCOVERY_REPORT"
    OPERATION_TYPE_GENERATE_DISCOVERY_REPORT = "GENERATE_DISCOVERY_REPORT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CREATE_SENSITIVE_TYPE"
    OPERATION_TYPE_CREATE_SENSITIVE_TYPE = "CREATE_SENSITIVE_TYPE"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "UPDATE_SENSITIVE_TYPE"
    OPERATION_TYPE_UPDATE_SENSITIVE_TYPE = "UPDATE_SENSITIVE_TYPE"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CREATE_MASKING_POLICY"
    OPERATION_TYPE_CREATE_MASKING_POLICY = "CREATE_MASKING_POLICY"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "UPDATE_MASKING_POLICY"
    OPERATION_TYPE_UPDATE_MASKING_POLICY = "UPDATE_MASKING_POLICY"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "DELETE_MASKING_POLICY"
    OPERATION_TYPE_DELETE_MASKING_POLICY = "DELETE_MASKING_POLICY"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "UPLOAD_MASKING_POLICY"
    OPERATION_TYPE_UPLOAD_MASKING_POLICY = "UPLOAD_MASKING_POLICY"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "GENERATE_MASKING_POLICY_FOR_DOWNLOAD"
    OPERATION_TYPE_GENERATE_MASKING_POLICY_FOR_DOWNLOAD = "GENERATE_MASKING_POLICY_FOR_DOWNLOAD"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CREATE_MASKING_COLUMN"
    OPERATION_TYPE_CREATE_MASKING_COLUMN = "CREATE_MASKING_COLUMN"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "UPDATE_MASKING_COLUMN"
    OPERATION_TYPE_UPDATE_MASKING_COLUMN = "UPDATE_MASKING_COLUMN"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "PATCH_MASKING_COLUMNS"
    OPERATION_TYPE_PATCH_MASKING_COLUMNS = "PATCH_MASKING_COLUMNS"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "GENERATE_MASKING_REPORT"
    OPERATION_TYPE_GENERATE_MASKING_REPORT = "GENERATE_MASKING_REPORT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "CREATE_LIBRARY_MASKING_FORMAT"
    OPERATION_TYPE_CREATE_LIBRARY_MASKING_FORMAT = "CREATE_LIBRARY_MASKING_FORMAT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "UPDATE_LIBRARY_MASKING_FORMAT"
    OPERATION_TYPE_UPDATE_LIBRARY_MASKING_FORMAT = "UPDATE_LIBRARY_MASKING_FORMAT"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "ADD_COLUMNS_FROM_SDM"
    OPERATION_TYPE_ADD_COLUMNS_FROM_SDM = "ADD_COLUMNS_FROM_SDM"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "MASKING_JOB"
    OPERATION_TYPE_MASKING_JOB = "MASKING_JOB"

    #: A constant which can be used with the status property of a WorkRequestSummary.
    #: This constant has a value of "ACCEPTED"
    STATUS_ACCEPTED = "ACCEPTED"

    #: A constant which can be used with the status property of a WorkRequestSummary.
    #: This constant has a value of "IN_PROGRESS"
    STATUS_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the status property of a WorkRequestSummary.
    #: This constant has a value of "FAILED"
    STATUS_FAILED = "FAILED"

    #: A constant which can be used with the status property of a WorkRequestSummary.
    #: This constant has a value of "SUCCEEDED"
    STATUS_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the status property of a WorkRequestSummary.
    #: This constant has a value of "CANCELING"
    STATUS_CANCELING = "CANCELING"

    #: A constant which can be used with the status property of a WorkRequestSummary.
    #: This constant has a value of "CANCELED"
    STATUS_CANCELED = "CANCELED"

    #: A constant which can be used with the status property of a WorkRequestSummary.
    #: This constant has a value of "SUSPENDING"
    STATUS_SUSPENDING = "SUSPENDING"

    #: A constant which can be used with the status property of a WorkRequestSummary.
    #: This constant has a value of "SUSPENDED"
    STATUS_SUSPENDED = "SUSPENDED"

    def __init__(self, **kwargs):
        """
        Initializes a new WorkRequestSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param operation_type:
            The value to assign to the operation_type property of this WorkRequestSummary.
            Allowed values for this property are: "ENABLE_DATA_SAFE_CONFIGURATION", "CREATE_PRIVATE_ENDPOINT", "UPDATE_PRIVATE_ENDPOINT", "DELETE_PRIVATE_ENDPOINT", "CHANGE_PRIVATE_ENDPOINT_COMPARTMENT", "CREATE_ONPREM_CONNECTOR", "UPDATE_ONPREM_CONNECTOR", "DELETE_ONPREM_CONNECTOR", "UPDATE_ONPREM_CONNECTOR_WALLET", "CHANGE_ONPREM_CONNECTOR_COMPARTMENT", "PROVISION_POLICY", "RETRIEVE_POLICY", "UPDATE_POLICY", "CHANGE_POLICY_COMPARTMENT", "CREATE_TARGET_DATABASE", "UPDATE_TARGET_DATABASE", "ACTIVATE_TARGET_DATABASE", "DEACTIVATE_TARGET_DATABASE", "DELETE_TARGET_DATABASE", "CHANGE_TARGET_DATABASE_COMPARTMENT", "CREATE_USER_ASSESSMENT", "ASSESS_USER_ASSESSMENT", "CREATE_SNAPSHOT_USER_ASSESSMENT", "CREATE_SCHEDULE_USER_ASSESSMENT", "COMPARE_WITH_BASELINE_USER_ASSESSMENT", "DELETE_USER_ASSESSMENT", "UPDATE_USER_ASSESSMENT", "CHANGE_USER_ASSESSMENT_COMPARTMENT", "SET_USER_ASSESSMENT_BASELINE", "UNSET_USER_ASSESSMENT_BASELINE", "GENERATE_USER_ASSESSMENT_REPORT", "CREATE_SECURITY_ASSESSMENT", "CREATE_SECURITY_ASSESSMENT_NOW", "ASSESS_SECURITY_ASSESSMENT", "CREATE_SNAPSHOT_SECURITY_ASSESSMENT", "CREATE_SCHEDULE_SECURITY_ASSESSMENT", "COMPARE_WITH_BASELINE_SECURITY_ASSESSMENT", "DELETE_SECURITY_ASSESSMENT", "UPDATE_SECURITY_ASSESSMENT", "CHANGE_SECURITY_ASSESSMENT_COMPARTMENT", "SET_SECURITY_ASSESSMENT_BASELINE", "UNSET_SECURITY_ASSESSMENT_BASELINE", "GENERATE_SECURITY_ASSESSMENT_REPORT", "CALCULATE_VOLUME", "CALCULATE_COLLECTED_VOLUME", "AUDIT_TRAIL", "DELETE_AUDIT_TRAIL", "DISCOVER_AUDIT_TRAILS", "UPDATE_AUDIT_TRAIL", "UPDATE_AUDIT_PROFILE", "AUDIT_CHANGE_COMPARTMENT", "CREATE_REPORT_DEFINITION", "UPDATE_REPORT_DEFINITION", "CHANGE_REPORT_DEFINITION_COMPARTMENT", "DELETE_REPORT_DEFINITION", "GENERATE_REPORT", "CHANGE_REPORT_COMPARTMENT", "DELETE_ARCHIVE_RETRIEVAL", "CREATE_ARCHIVE_RETRIEVAL", "UPDATE_ARCHIVE_RETRIEVAL", "CHANGE_ARCHIVE_RETRIEVAL_COMPARTMENT", "UPDATE_ALERT", "TARGET_ALERT_POLICY_ASSOCIATION", "CREATE_SENSITIVE_DATA_MODEL", "UPDATE_SENSITIVE_DATA_MODEL", "DELETE_SENSITIVE_DATA_MODEL", "UPLOAD_SENSITIVE_DATA_MODEL", "GENERATE_SENSITIVE_DATA_MODEL_FOR_DOWNLOAD", "CREATE_SENSITIVE_COLUMN", "UPDATE_SENSITIVE_COLUMN", "PATCH_SENSITIVE_COLUMNS", "CREATE_DISCOVERY_JOB", "DELETE_DISCOVERY_JOB", "PATCH_DISCOVERY_JOB_RESULT", "APPLY_DISCOVERY_JOB_RESULT", "GENERATE_DISCOVERY_REPORT", "CREATE_SENSITIVE_TYPE", "UPDATE_SENSITIVE_TYPE", "CREATE_MASKING_POLICY", "UPDATE_MASKING_POLICY", "DELETE_MASKING_POLICY", "UPLOAD_MASKING_POLICY", "GENERATE_MASKING_POLICY_FOR_DOWNLOAD", "CREATE_MASKING_COLUMN", "UPDATE_MASKING_COLUMN", "PATCH_MASKING_COLUMNS", "GENERATE_MASKING_REPORT", "CREATE_LIBRARY_MASKING_FORMAT", "UPDATE_LIBRARY_MASKING_FORMAT", "ADD_COLUMNS_FROM_SDM", "MASKING_JOB", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type operation_type: str

        :param status:
            The value to assign to the status property of this WorkRequestSummary.
            Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELING", "CANCELED", "SUSPENDING", "SUSPENDED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param id:
            The value to assign to the id property of this WorkRequestSummary.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this WorkRequestSummary.
        :type compartment_id: str

        :param resources:
            The value to assign to the resources property of this WorkRequestSummary.
        :type resources: list[oci.data_safe.models.WorkRequestResource]

        :param percent_complete:
            The value to assign to the percent_complete property of this WorkRequestSummary.
        :type percent_complete: float

        :param time_accepted:
            The value to assign to the time_accepted property of this WorkRequestSummary.
        :type time_accepted: datetime

        :param time_started:
            The value to assign to the time_started property of this WorkRequestSummary.
        :type time_started: datetime

        :param time_finished:
            The value to assign to the time_finished property of this WorkRequestSummary.
        :type time_finished: datetime

        """
        self.swagger_types = {
            'operation_type': 'str',
            'status': 'str',
            'id': 'str',
            'compartment_id': 'str',
            'resources': 'list[WorkRequestResource]',
            'percent_complete': 'float',
            'time_accepted': 'datetime',
            'time_started': 'datetime',
            'time_finished': 'datetime'
        }

        self.attribute_map = {
            'operation_type': 'operationType',
            'status': 'status',
            'id': 'id',
            'compartment_id': 'compartmentId',
            'resources': 'resources',
            'percent_complete': 'percentComplete',
            'time_accepted': 'timeAccepted',
            'time_started': 'timeStarted',
            'time_finished': 'timeFinished'
        }

        self._operation_type = None
        self._status = None
        self._id = None
        self._compartment_id = None
        self._resources = None
        self._percent_complete = None
        self._time_accepted = None
        self._time_started = None
        self._time_finished = None

    @property
    def operation_type(self):
        """
        **[Required]** Gets the operation_type of this WorkRequestSummary.
        The asynchronous operation tracked by this work request.

        Allowed values for this property are: "ENABLE_DATA_SAFE_CONFIGURATION", "CREATE_PRIVATE_ENDPOINT", "UPDATE_PRIVATE_ENDPOINT", "DELETE_PRIVATE_ENDPOINT", "CHANGE_PRIVATE_ENDPOINT_COMPARTMENT", "CREATE_ONPREM_CONNECTOR", "UPDATE_ONPREM_CONNECTOR", "DELETE_ONPREM_CONNECTOR", "UPDATE_ONPREM_CONNECTOR_WALLET", "CHANGE_ONPREM_CONNECTOR_COMPARTMENT", "PROVISION_POLICY", "RETRIEVE_POLICY", "UPDATE_POLICY", "CHANGE_POLICY_COMPARTMENT", "CREATE_TARGET_DATABASE", "UPDATE_TARGET_DATABASE", "ACTIVATE_TARGET_DATABASE", "DEACTIVATE_TARGET_DATABASE", "DELETE_TARGET_DATABASE", "CHANGE_TARGET_DATABASE_COMPARTMENT", "CREATE_USER_ASSESSMENT", "ASSESS_USER_ASSESSMENT", "CREATE_SNAPSHOT_USER_ASSESSMENT", "CREATE_SCHEDULE_USER_ASSESSMENT", "COMPARE_WITH_BASELINE_USER_ASSESSMENT", "DELETE_USER_ASSESSMENT", "UPDATE_USER_ASSESSMENT", "CHANGE_USER_ASSESSMENT_COMPARTMENT", "SET_USER_ASSESSMENT_BASELINE", "UNSET_USER_ASSESSMENT_BASELINE", "GENERATE_USER_ASSESSMENT_REPORT", "CREATE_SECURITY_ASSESSMENT", "CREATE_SECURITY_ASSESSMENT_NOW", "ASSESS_SECURITY_ASSESSMENT", "CREATE_SNAPSHOT_SECURITY_ASSESSMENT", "CREATE_SCHEDULE_SECURITY_ASSESSMENT", "COMPARE_WITH_BASELINE_SECURITY_ASSESSMENT", "DELETE_SECURITY_ASSESSMENT", "UPDATE_SECURITY_ASSESSMENT", "CHANGE_SECURITY_ASSESSMENT_COMPARTMENT", "SET_SECURITY_ASSESSMENT_BASELINE", "UNSET_SECURITY_ASSESSMENT_BASELINE", "GENERATE_SECURITY_ASSESSMENT_REPORT", "CALCULATE_VOLUME", "CALCULATE_COLLECTED_VOLUME", "AUDIT_TRAIL", "DELETE_AUDIT_TRAIL", "DISCOVER_AUDIT_TRAILS", "UPDATE_AUDIT_TRAIL", "UPDATE_AUDIT_PROFILE", "AUDIT_CHANGE_COMPARTMENT", "CREATE_REPORT_DEFINITION", "UPDATE_REPORT_DEFINITION", "CHANGE_REPORT_DEFINITION_COMPARTMENT", "DELETE_REPORT_DEFINITION", "GENERATE_REPORT", "CHANGE_REPORT_COMPARTMENT", "DELETE_ARCHIVE_RETRIEVAL", "CREATE_ARCHIVE_RETRIEVAL", "UPDATE_ARCHIVE_RETRIEVAL", "CHANGE_ARCHIVE_RETRIEVAL_COMPARTMENT", "UPDATE_ALERT", "TARGET_ALERT_POLICY_ASSOCIATION", "CREATE_SENSITIVE_DATA_MODEL", "UPDATE_SENSITIVE_DATA_MODEL", "DELETE_SENSITIVE_DATA_MODEL", "UPLOAD_SENSITIVE_DATA_MODEL", "GENERATE_SENSITIVE_DATA_MODEL_FOR_DOWNLOAD", "CREATE_SENSITIVE_COLUMN", "UPDATE_SENSITIVE_COLUMN", "PATCH_SENSITIVE_COLUMNS", "CREATE_DISCOVERY_JOB", "DELETE_DISCOVERY_JOB", "PATCH_DISCOVERY_JOB_RESULT", "APPLY_DISCOVERY_JOB_RESULT", "GENERATE_DISCOVERY_REPORT", "CREATE_SENSITIVE_TYPE", "UPDATE_SENSITIVE_TYPE", "CREATE_MASKING_POLICY", "UPDATE_MASKING_POLICY", "DELETE_MASKING_POLICY", "UPLOAD_MASKING_POLICY", "GENERATE_MASKING_POLICY_FOR_DOWNLOAD", "CREATE_MASKING_COLUMN", "UPDATE_MASKING_COLUMN", "PATCH_MASKING_COLUMNS", "GENERATE_MASKING_REPORT", "CREATE_LIBRARY_MASKING_FORMAT", "UPDATE_LIBRARY_MASKING_FORMAT", "ADD_COLUMNS_FROM_SDM", "MASKING_JOB", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The operation_type of this WorkRequestSummary.
        :rtype: str
        """
        return self._operation_type

    @operation_type.setter
    def operation_type(self, operation_type):
        """
        Sets the operation_type of this WorkRequestSummary.
        The asynchronous operation tracked by this work request.


        :param operation_type: The operation_type of this WorkRequestSummary.
        :type: str
        """
        allowed_values = ["ENABLE_DATA_SAFE_CONFIGURATION", "CREATE_PRIVATE_ENDPOINT", "UPDATE_PRIVATE_ENDPOINT", "DELETE_PRIVATE_ENDPOINT", "CHANGE_PRIVATE_ENDPOINT_COMPARTMENT", "CREATE_ONPREM_CONNECTOR", "UPDATE_ONPREM_CONNECTOR", "DELETE_ONPREM_CONNECTOR", "UPDATE_ONPREM_CONNECTOR_WALLET", "CHANGE_ONPREM_CONNECTOR_COMPARTMENT", "PROVISION_POLICY", "RETRIEVE_POLICY", "UPDATE_POLICY", "CHANGE_POLICY_COMPARTMENT", "CREATE_TARGET_DATABASE", "UPDATE_TARGET_DATABASE", "ACTIVATE_TARGET_DATABASE", "DEACTIVATE_TARGET_DATABASE", "DELETE_TARGET_DATABASE", "CHANGE_TARGET_DATABASE_COMPARTMENT", "CREATE_USER_ASSESSMENT", "ASSESS_USER_ASSESSMENT", "CREATE_SNAPSHOT_USER_ASSESSMENT", "CREATE_SCHEDULE_USER_ASSESSMENT", "COMPARE_WITH_BASELINE_USER_ASSESSMENT", "DELETE_USER_ASSESSMENT", "UPDATE_USER_ASSESSMENT", "CHANGE_USER_ASSESSMENT_COMPARTMENT", "SET_USER_ASSESSMENT_BASELINE", "UNSET_USER_ASSESSMENT_BASELINE", "GENERATE_USER_ASSESSMENT_REPORT", "CREATE_SECURITY_ASSESSMENT", "CREATE_SECURITY_ASSESSMENT_NOW", "ASSESS_SECURITY_ASSESSMENT", "CREATE_SNAPSHOT_SECURITY_ASSESSMENT", "CREATE_SCHEDULE_SECURITY_ASSESSMENT", "COMPARE_WITH_BASELINE_SECURITY_ASSESSMENT", "DELETE_SECURITY_ASSESSMENT", "UPDATE_SECURITY_ASSESSMENT", "CHANGE_SECURITY_ASSESSMENT_COMPARTMENT", "SET_SECURITY_ASSESSMENT_BASELINE", "UNSET_SECURITY_ASSESSMENT_BASELINE", "GENERATE_SECURITY_ASSESSMENT_REPORT", "CALCULATE_VOLUME", "CALCULATE_COLLECTED_VOLUME", "AUDIT_TRAIL", "DELETE_AUDIT_TRAIL", "DISCOVER_AUDIT_TRAILS", "UPDATE_AUDIT_TRAIL", "UPDATE_AUDIT_PROFILE", "AUDIT_CHANGE_COMPARTMENT", "CREATE_REPORT_DEFINITION", "UPDATE_REPORT_DEFINITION", "CHANGE_REPORT_DEFINITION_COMPARTMENT", "DELETE_REPORT_DEFINITION", "GENERATE_REPORT", "CHANGE_REPORT_COMPARTMENT", "DELETE_ARCHIVE_RETRIEVAL", "CREATE_ARCHIVE_RETRIEVAL", "UPDATE_ARCHIVE_RETRIEVAL", "CHANGE_ARCHIVE_RETRIEVAL_COMPARTMENT", "UPDATE_ALERT", "TARGET_ALERT_POLICY_ASSOCIATION", "CREATE_SENSITIVE_DATA_MODEL", "UPDATE_SENSITIVE_DATA_MODEL", "DELETE_SENSITIVE_DATA_MODEL", "UPLOAD_SENSITIVE_DATA_MODEL", "GENERATE_SENSITIVE_DATA_MODEL_FOR_DOWNLOAD", "CREATE_SENSITIVE_COLUMN", "UPDATE_SENSITIVE_COLUMN", "PATCH_SENSITIVE_COLUMNS", "CREATE_DISCOVERY_JOB", "DELETE_DISCOVERY_JOB", "PATCH_DISCOVERY_JOB_RESULT", "APPLY_DISCOVERY_JOB_RESULT", "GENERATE_DISCOVERY_REPORT", "CREATE_SENSITIVE_TYPE", "UPDATE_SENSITIVE_TYPE", "CREATE_MASKING_POLICY", "UPDATE_MASKING_POLICY", "DELETE_MASKING_POLICY", "UPLOAD_MASKING_POLICY", "GENERATE_MASKING_POLICY_FOR_DOWNLOAD", "CREATE_MASKING_COLUMN", "UPDATE_MASKING_COLUMN", "PATCH_MASKING_COLUMNS", "GENERATE_MASKING_REPORT", "CREATE_LIBRARY_MASKING_FORMAT", "UPDATE_LIBRARY_MASKING_FORMAT", "ADD_COLUMNS_FROM_SDM", "MASKING_JOB"]
        if not value_allowed_none_or_none_sentinel(operation_type, allowed_values):
            operation_type = 'UNKNOWN_ENUM_VALUE'
        self._operation_type = operation_type

    @property
    def status(self):
        """
        **[Required]** Gets the status of this WorkRequestSummary.
        The current status of the work request.

        Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELING", "CANCELED", "SUSPENDING", "SUSPENDED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this WorkRequestSummary.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this WorkRequestSummary.
        The current status of the work request.


        :param status: The status of this WorkRequestSummary.
        :type: str
        """
        allowed_values = ["ACCEPTED", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELING", "CANCELED", "SUSPENDING", "SUSPENDED"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def id(self):
        """
        **[Required]** Gets the id of this WorkRequestSummary.
        The OCID of the work request.


        :return: The id of this WorkRequestSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this WorkRequestSummary.
        The OCID of the work request.


        :param id: The id of this WorkRequestSummary.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this WorkRequestSummary.
        The OCID of the compartment that contains the work request.


        :return: The compartment_id of this WorkRequestSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this WorkRequestSummary.
        The OCID of the compartment that contains the work request.


        :param compartment_id: The compartment_id of this WorkRequestSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def resources(self):
        """
        **[Required]** Gets the resources of this WorkRequestSummary.
        The resources that are affected by the work request.


        :return: The resources of this WorkRequestSummary.
        :rtype: list[oci.data_safe.models.WorkRequestResource]
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """
        Sets the resources of this WorkRequestSummary.
        The resources that are affected by the work request.


        :param resources: The resources of this WorkRequestSummary.
        :type: list[oci.data_safe.models.WorkRequestResource]
        """
        self._resources = resources

    @property
    def percent_complete(self):
        """
        **[Required]** Gets the percent_complete of this WorkRequestSummary.
        Progress of the work request in percentage.


        :return: The percent_complete of this WorkRequestSummary.
        :rtype: float
        """
        return self._percent_complete

    @percent_complete.setter
    def percent_complete(self, percent_complete):
        """
        Sets the percent_complete of this WorkRequestSummary.
        Progress of the work request in percentage.


        :param percent_complete: The percent_complete of this WorkRequestSummary.
        :type: float
        """
        self._percent_complete = percent_complete

    @property
    def time_accepted(self):
        """
        **[Required]** Gets the time_accepted of this WorkRequestSummary.
        The date and time the work request was accepted, in the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_accepted of this WorkRequestSummary.
        :rtype: datetime
        """
        return self._time_accepted

    @time_accepted.setter
    def time_accepted(self, time_accepted):
        """
        Sets the time_accepted of this WorkRequestSummary.
        The date and time the work request was accepted, in the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_accepted: The time_accepted of this WorkRequestSummary.
        :type: datetime
        """
        self._time_accepted = time_accepted

    @property
    def time_started(self):
        """
        Gets the time_started of this WorkRequestSummary.
        The date and time the work request transitioned from ACCEPTED to IN_PROGRESS, in the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_started of this WorkRequestSummary.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this WorkRequestSummary.
        The date and time the work request transitioned from ACCEPTED to IN_PROGRESS, in the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_started: The time_started of this WorkRequestSummary.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def time_finished(self):
        """
        Gets the time_finished of this WorkRequestSummary.
        The date and time the work request reached a terminal state, either FAILED or SUCCEEDED, in the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_finished of this WorkRequestSummary.
        :rtype: datetime
        """
        return self._time_finished

    @time_finished.setter
    def time_finished(self, time_finished):
        """
        Sets the time_finished of this WorkRequestSummary.
        The date and time the work request reached a terminal state, either FAILED or SUCCEEDED, in the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_finished: The time_finished of this WorkRequestSummary.
        :type: datetime
        """
        self._time_finished = time_finished

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateWebAppFirewallDetails(object):
    """
    The information about new Web App Firewall.
    """

    #: A constant which can be used with the backend_type property of a CreateWebAppFirewallDetails.
    #: This constant has a value of "LOAD_BALANCER"
    BACKEND_TYPE_LOAD_BALANCER = "LOAD_BALANCER"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateWebAppFirewallDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.waf.models.CreateWebAppFirewallLoadBalancerDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateWebAppFirewallDetails.
        :type display_name: str

        :param backend_type:
            The value to assign to the backend_type property of this CreateWebAppFirewallDetails.
            Allowed values for this property are: "LOAD_BALANCER"
        :type backend_type: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateWebAppFirewallDetails.
        :type compartment_id: str

        :param web_app_firewall_policy_id:
            The value to assign to the web_app_firewall_policy_id property of this CreateWebAppFirewallDetails.
        :type web_app_firewall_policy_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateWebAppFirewallDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateWebAppFirewallDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this CreateWebAppFirewallDetails.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'backend_type': 'str',
            'compartment_id': 'str',
            'web_app_firewall_policy_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'backend_type': 'backendType',
            'compartment_id': 'compartmentId',
            'web_app_firewall_policy_id': 'webAppFirewallPolicyId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._display_name = None
        self._backend_type = None
        self._compartment_id = None
        self._web_app_firewall_policy_id = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['backendType']

        if type == 'LOAD_BALANCER':
            return 'CreateWebAppFirewallLoadBalancerDetails'
        else:
            return 'CreateWebAppFirewallDetails'

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateWebAppFirewallDetails.
        WebAppFirewall display name, can be renamed.


        :return: The display_name of this CreateWebAppFirewallDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateWebAppFirewallDetails.
        WebAppFirewall display name, can be renamed.


        :param display_name: The display_name of this CreateWebAppFirewallDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def backend_type(self):
        """
        **[Required]** Gets the backend_type of this CreateWebAppFirewallDetails.
        Type of the WebAppFirewall, as example LOAD_BALANCER.

        Allowed values for this property are: "LOAD_BALANCER"


        :return: The backend_type of this CreateWebAppFirewallDetails.
        :rtype: str
        """
        return self._backend_type

    @backend_type.setter
    def backend_type(self, backend_type):
        """
        Sets the backend_type of this CreateWebAppFirewallDetails.
        Type of the WebAppFirewall, as example LOAD_BALANCER.


        :param backend_type: The backend_type of this CreateWebAppFirewallDetails.
        :type: str
        """
        allowed_values = ["LOAD_BALANCER"]
        if not value_allowed_none_or_none_sentinel(backend_type, allowed_values):
            raise ValueError(
                "Invalid value for `backend_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._backend_type = backend_type

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateWebAppFirewallDetails.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateWebAppFirewallDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateWebAppFirewallDetails.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateWebAppFirewallDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def web_app_firewall_policy_id(self):
        """
        **[Required]** Gets the web_app_firewall_policy_id of this CreateWebAppFirewallDetails.
        The `OCID`__ of WebAppFirewallPolicy, which is attached to the resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The web_app_firewall_policy_id of this CreateWebAppFirewallDetails.
        :rtype: str
        """
        return self._web_app_firewall_policy_id

    @web_app_firewall_policy_id.setter
    def web_app_firewall_policy_id(self, web_app_firewall_policy_id):
        """
        Sets the web_app_firewall_policy_id of this CreateWebAppFirewallDetails.
        The `OCID`__ of WebAppFirewallPolicy, which is attached to the resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param web_app_firewall_policy_id: The web_app_firewall_policy_id of this CreateWebAppFirewallDetails.
        :type: str
        """
        self._web_app_firewall_policy_id = web_app_firewall_policy_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateWebAppFirewallDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CreateWebAppFirewallDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateWebAppFirewallDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CreateWebAppFirewallDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateWebAppFirewallDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CreateWebAppFirewallDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateWebAppFirewallDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CreateWebAppFirewallDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this CreateWebAppFirewallDetails.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this CreateWebAppFirewallDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this CreateWebAppFirewallDetails.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this CreateWebAppFirewallDetails.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InvoiceSummary(object):
    """
    Invoice list elements
    """

    #: A constant which can be used with the invoice_status property of a InvoiceSummary.
    #: This constant has a value of "OPEN"
    INVOICE_STATUS_OPEN = "OPEN"

    #: A constant which can be used with the invoice_status property of a InvoiceSummary.
    #: This constant has a value of "PAST_DUE"
    INVOICE_STATUS_PAST_DUE = "PAST_DUE"

    #: A constant which can be used with the invoice_status property of a InvoiceSummary.
    #: This constant has a value of "PAYMENT_SUBMITTED"
    INVOICE_STATUS_PAYMENT_SUBMITTED = "PAYMENT_SUBMITTED"

    #: A constant which can be used with the invoice_status property of a InvoiceSummary.
    #: This constant has a value of "CLOSED"
    INVOICE_STATUS_CLOSED = "CLOSED"

    #: A constant which can be used with the invoice_type property of a InvoiceSummary.
    #: This constant has a value of "HARDWARE"
    INVOICE_TYPE_HARDWARE = "HARDWARE"

    #: A constant which can be used with the invoice_type property of a InvoiceSummary.
    #: This constant has a value of "SUBSCRIPTION"
    INVOICE_TYPE_SUBSCRIPTION = "SUBSCRIPTION"

    #: A constant which can be used with the invoice_type property of a InvoiceSummary.
    #: This constant has a value of "SUPPORT"
    INVOICE_TYPE_SUPPORT = "SUPPORT"

    #: A constant which can be used with the invoice_type property of a InvoiceSummary.
    #: This constant has a value of "LICENSE"
    INVOICE_TYPE_LICENSE = "LICENSE"

    #: A constant which can be used with the invoice_type property of a InvoiceSummary.
    #: This constant has a value of "EDUCATION"
    INVOICE_TYPE_EDUCATION = "EDUCATION"

    #: A constant which can be used with the invoice_type property of a InvoiceSummary.
    #: This constant has a value of "CONSULTING"
    INVOICE_TYPE_CONSULTING = "CONSULTING"

    #: A constant which can be used with the invoice_type property of a InvoiceSummary.
    #: This constant has a value of "SERVICE"
    INVOICE_TYPE_SERVICE = "SERVICE"

    #: A constant which can be used with the invoice_type property of a InvoiceSummary.
    #: This constant has a value of "USAGE"
    INVOICE_TYPE_USAGE = "USAGE"

    def __init__(self, **kwargs):
        """
        Initializes a new InvoiceSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param invoice_id:
            The value to assign to the invoice_id property of this InvoiceSummary.
        :type invoice_id: str

        :param invoice_number:
            The value to assign to the invoice_number property of this InvoiceSummary.
        :type invoice_number: str

        :param internal_invoice_id:
            The value to assign to the internal_invoice_id property of this InvoiceSummary.
        :type internal_invoice_id: str

        :param is_credit_card_payable:
            The value to assign to the is_credit_card_payable property of this InvoiceSummary.
        :type is_credit_card_payable: bool

        :param invoice_status:
            The value to assign to the invoice_status property of this InvoiceSummary.
            Allowed values for this property are: "OPEN", "PAST_DUE", "PAYMENT_SUBMITTED", "CLOSED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type invoice_status: str

        :param invoice_type:
            The value to assign to the invoice_type property of this InvoiceSummary.
            Allowed values for this property are: "HARDWARE", "SUBSCRIPTION", "SUPPORT", "LICENSE", "EDUCATION", "CONSULTING", "SERVICE", "USAGE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type invoice_type: str

        :param is_paid:
            The value to assign to the is_paid property of this InvoiceSummary.
        :type is_paid: bool

        :param is_payable:
            The value to assign to the is_payable property of this InvoiceSummary.
        :type is_payable: bool

        :param invoice_amount:
            The value to assign to the invoice_amount property of this InvoiceSummary.
        :type invoice_amount: float

        :param invoice_amount_due:
            The value to assign to the invoice_amount_due property of this InvoiceSummary.
        :type invoice_amount_due: float

        :param invoice_amount_credited:
            The value to assign to the invoice_amount_credited property of this InvoiceSummary.
        :type invoice_amount_credited: float

        :param invoice_amount_adjusted:
            The value to assign to the invoice_amount_adjusted property of this InvoiceSummary.
        :type invoice_amount_adjusted: float

        :param invoice_amount_applied:
            The value to assign to the invoice_amount_applied property of this InvoiceSummary.
        :type invoice_amount_applied: float

        :param time_invoice_due:
            The value to assign to the time_invoice_due property of this InvoiceSummary.
        :type time_invoice_due: datetime

        :param is_payment_failed:
            The value to assign to the is_payment_failed property of this InvoiceSummary.
        :type is_payment_failed: bool

        :param invoice_amount_in_dispute:
            The value to assign to the invoice_amount_in_dispute property of this InvoiceSummary.
        :type invoice_amount_in_dispute: float

        :param invoice_ref_number:
            The value to assign to the invoice_ref_number property of this InvoiceSummary.
        :type invoice_ref_number: str

        :param invoice_po_number:
            The value to assign to the invoice_po_number property of this InvoiceSummary.
        :type invoice_po_number: str

        :param time_invoice:
            The value to assign to the time_invoice property of this InvoiceSummary.
        :type time_invoice: datetime

        :param currency:
            The value to assign to the currency property of this InvoiceSummary.
        :type currency: oci.osp_gateway.models.Currency

        :param is_pdf_email_available:
            The value to assign to the is_pdf_email_available property of this InvoiceSummary.
        :type is_pdf_email_available: bool

        :param is_display_view_pdf:
            The value to assign to the is_display_view_pdf property of this InvoiceSummary.
        :type is_display_view_pdf: bool

        :param is_display_download_pdf:
            The value to assign to the is_display_download_pdf property of this InvoiceSummary.
        :type is_display_download_pdf: bool

        :param last_payment_detail:
            The value to assign to the last_payment_detail property of this InvoiceSummary.
        :type last_payment_detail: oci.osp_gateway.models.PaymentDetail

        :param party_name:
            The value to assign to the party_name property of this InvoiceSummary.
        :type party_name: str

        :param subscription_ids:
            The value to assign to the subscription_ids property of this InvoiceSummary.
        :type subscription_ids: list[str]

        """
        self.swagger_types = {
            'invoice_id': 'str',
            'invoice_number': 'str',
            'internal_invoice_id': 'str',
            'is_credit_card_payable': 'bool',
            'invoice_status': 'str',
            'invoice_type': 'str',
            'is_paid': 'bool',
            'is_payable': 'bool',
            'invoice_amount': 'float',
            'invoice_amount_due': 'float',
            'invoice_amount_credited': 'float',
            'invoice_amount_adjusted': 'float',
            'invoice_amount_applied': 'float',
            'time_invoice_due': 'datetime',
            'is_payment_failed': 'bool',
            'invoice_amount_in_dispute': 'float',
            'invoice_ref_number': 'str',
            'invoice_po_number': 'str',
            'time_invoice': 'datetime',
            'currency': 'Currency',
            'is_pdf_email_available': 'bool',
            'is_display_view_pdf': 'bool',
            'is_display_download_pdf': 'bool',
            'last_payment_detail': 'PaymentDetail',
            'party_name': 'str',
            'subscription_ids': 'list[str]'
        }

        self.attribute_map = {
            'invoice_id': 'invoiceId',
            'invoice_number': 'invoiceNumber',
            'internal_invoice_id': 'internalInvoiceId',
            'is_credit_card_payable': 'isCreditCardPayable',
            'invoice_status': 'invoiceStatus',
            'invoice_type': 'invoiceType',
            'is_paid': 'isPaid',
            'is_payable': 'isPayable',
            'invoice_amount': 'invoiceAmount',
            'invoice_amount_due': 'invoiceAmountDue',
            'invoice_amount_credited': 'invoiceAmountCredited',
            'invoice_amount_adjusted': 'invoiceAmountAdjusted',
            'invoice_amount_applied': 'invoiceAmountApplied',
            'time_invoice_due': 'timeInvoiceDue',
            'is_payment_failed': 'isPaymentFailed',
            'invoice_amount_in_dispute': 'invoiceAmountInDispute',
            'invoice_ref_number': 'invoiceRefNumber',
            'invoice_po_number': 'invoicePoNumber',
            'time_invoice': 'timeInvoice',
            'currency': 'currency',
            'is_pdf_email_available': 'isPdfEmailAvailable',
            'is_display_view_pdf': 'isDisplayViewPdf',
            'is_display_download_pdf': 'isDisplayDownloadPdf',
            'last_payment_detail': 'lastPaymentDetail',
            'party_name': 'partyName',
            'subscription_ids': 'subscriptionIds'
        }

        self._invoice_id = None
        self._invoice_number = None
        self._internal_invoice_id = None
        self._is_credit_card_payable = None
        self._invoice_status = None
        self._invoice_type = None
        self._is_paid = None
        self._is_payable = None
        self._invoice_amount = None
        self._invoice_amount_due = None
        self._invoice_amount_credited = None
        self._invoice_amount_adjusted = None
        self._invoice_amount_applied = None
        self._time_invoice_due = None
        self._is_payment_failed = None
        self._invoice_amount_in_dispute = None
        self._invoice_ref_number = None
        self._invoice_po_number = None
        self._time_invoice = None
        self._currency = None
        self._is_pdf_email_available = None
        self._is_display_view_pdf = None
        self._is_display_download_pdf = None
        self._last_payment_detail = None
        self._party_name = None
        self._subscription_ids = None

    @property
    def invoice_id(self):
        """
        **[Required]** Gets the invoice_id of this InvoiceSummary.
        Invoice identifier


        :return: The invoice_id of this InvoiceSummary.
        :rtype: str
        """
        return self._invoice_id

    @invoice_id.setter
    def invoice_id(self, invoice_id):
        """
        Sets the invoice_id of this InvoiceSummary.
        Invoice identifier


        :param invoice_id: The invoice_id of this InvoiceSummary.
        :type: str
        """
        self._invoice_id = invoice_id

    @property
    def invoice_number(self):
        """
        Gets the invoice_number of this InvoiceSummary.
        Invoice external reference


        :return: The invoice_number of this InvoiceSummary.
        :rtype: str
        """
        return self._invoice_number

    @invoice_number.setter
    def invoice_number(self, invoice_number):
        """
        Sets the invoice_number of this InvoiceSummary.
        Invoice external reference


        :param invoice_number: The invoice_number of this InvoiceSummary.
        :type: str
        """
        self._invoice_number = invoice_number

    @property
    def internal_invoice_id(self):
        """
        Gets the internal_invoice_id of this InvoiceSummary.
        PC invoice identifier


        :return: The internal_invoice_id of this InvoiceSummary.
        :rtype: str
        """
        return self._internal_invoice_id

    @internal_invoice_id.setter
    def internal_invoice_id(self, internal_invoice_id):
        """
        Sets the internal_invoice_id of this InvoiceSummary.
        PC invoice identifier


        :param internal_invoice_id: The internal_invoice_id of this InvoiceSummary.
        :type: str
        """
        self._internal_invoice_id = internal_invoice_id

    @property
    def is_credit_card_payable(self):
        """
        Gets the is_credit_card_payable of this InvoiceSummary.
        Is credit card payment eligible


        :return: The is_credit_card_payable of this InvoiceSummary.
        :rtype: bool
        """
        return self._is_credit_card_payable

    @is_credit_card_payable.setter
    def is_credit_card_payable(self, is_credit_card_payable):
        """
        Sets the is_credit_card_payable of this InvoiceSummary.
        Is credit card payment eligible


        :param is_credit_card_payable: The is_credit_card_payable of this InvoiceSummary.
        :type: bool
        """
        self._is_credit_card_payable = is_credit_card_payable

    @property
    def invoice_status(self):
        """
        Gets the invoice_status of this InvoiceSummary.
        Invoice status

        Allowed values for this property are: "OPEN", "PAST_DUE", "PAYMENT_SUBMITTED", "CLOSED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The invoice_status of this InvoiceSummary.
        :rtype: str
        """
        return self._invoice_status

    @invoice_status.setter
    def invoice_status(self, invoice_status):
        """
        Sets the invoice_status of this InvoiceSummary.
        Invoice status


        :param invoice_status: The invoice_status of this InvoiceSummary.
        :type: str
        """
        allowed_values = ["OPEN", "PAST_DUE", "PAYMENT_SUBMITTED", "CLOSED"]
        if not value_allowed_none_or_none_sentinel(invoice_status, allowed_values):
            invoice_status = 'UNKNOWN_ENUM_VALUE'
        self._invoice_status = invoice_status

    @property
    def invoice_type(self):
        """
        Gets the invoice_type of this InvoiceSummary.
        Type of invoice

        Allowed values for this property are: "HARDWARE", "SUBSCRIPTION", "SUPPORT", "LICENSE", "EDUCATION", "CONSULTING", "SERVICE", "USAGE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The invoice_type of this InvoiceSummary.
        :rtype: str
        """
        return self._invoice_type

    @invoice_type.setter
    def invoice_type(self, invoice_type):
        """
        Sets the invoice_type of this InvoiceSummary.
        Type of invoice


        :param invoice_type: The invoice_type of this InvoiceSummary.
        :type: str
        """
        allowed_values = ["HARDWARE", "SUBSCRIPTION", "SUPPORT", "LICENSE", "EDUCATION", "CONSULTING", "SERVICE", "USAGE"]
        if not value_allowed_none_or_none_sentinel(invoice_type, allowed_values):
            invoice_type = 'UNKNOWN_ENUM_VALUE'
        self._invoice_type = invoice_type

    @property
    def is_paid(self):
        """
        Gets the is_paid of this InvoiceSummary.
        Is the invoice has been already payed


        :return: The is_paid of this InvoiceSummary.
        :rtype: bool
        """
        return self._is_paid

    @is_paid.setter
    def is_paid(self, is_paid):
        """
        Sets the is_paid of this InvoiceSummary.
        Is the invoice has been already payed


        :param is_paid: The is_paid of this InvoiceSummary.
        :type: bool
        """
        self._is_paid = is_paid

    @property
    def is_payable(self):
        """
        Gets the is_payable of this InvoiceSummary.
        Whether invoice can be payed


        :return: The is_payable of this InvoiceSummary.
        :rtype: bool
        """
        return self._is_payable

    @is_payable.setter
    def is_payable(self, is_payable):
        """
        Sets the is_payable of this InvoiceSummary.
        Whether invoice can be payed


        :param is_payable: The is_payable of this InvoiceSummary.
        :type: bool
        """
        self._is_payable = is_payable

    @property
    def invoice_amount(self):
        """
        Gets the invoice_amount of this InvoiceSummary.
        Invoice amount


        :return: The invoice_amount of this InvoiceSummary.
        :rtype: float
        """
        return self._invoice_amount

    @invoice_amount.setter
    def invoice_amount(self, invoice_amount):
        """
        Sets the invoice_amount of this InvoiceSummary.
        Invoice amount


        :param invoice_amount: The invoice_amount of this InvoiceSummary.
        :type: float
        """
        self._invoice_amount = invoice_amount

    @property
    def invoice_amount_due(self):
        """
        Gets the invoice_amount_due of this InvoiceSummary.
        Invoice amount due


        :return: The invoice_amount_due of this InvoiceSummary.
        :rtype: float
        """
        return self._invoice_amount_due

    @invoice_amount_due.setter
    def invoice_amount_due(self, invoice_amount_due):
        """
        Sets the invoice_amount_due of this InvoiceSummary.
        Invoice amount due


        :param invoice_amount_due: The invoice_amount_due of this InvoiceSummary.
        :type: float
        """
        self._invoice_amount_due = invoice_amount_due

    @property
    def invoice_amount_credited(self):
        """
        Gets the invoice_amount_credited of this InvoiceSummary.
        Invoice amount credit


        :return: The invoice_amount_credited of this InvoiceSummary.
        :rtype: float
        """
        return self._invoice_amount_credited

    @invoice_amount_credited.setter
    def invoice_amount_credited(self, invoice_amount_credited):
        """
        Sets the invoice_amount_credited of this InvoiceSummary.
        Invoice amount credit


        :param invoice_amount_credited: The invoice_amount_credited of this InvoiceSummary.
        :type: float
        """
        self._invoice_amount_credited = invoice_amount_credited

    @property
    def invoice_amount_adjusted(self):
        """
        Gets the invoice_amount_adjusted of this InvoiceSummary.
        Invoice amount adjust


        :return: The invoice_amount_adjusted of this InvoiceSummary.
        :rtype: float
        """
        return self._invoice_amount_adjusted

    @invoice_amount_adjusted.setter
    def invoice_amount_adjusted(self, invoice_amount_adjusted):
        """
        Sets the invoice_amount_adjusted of this InvoiceSummary.
        Invoice amount adjust


        :param invoice_amount_adjusted: The invoice_amount_adjusted of this InvoiceSummary.
        :type: float
        """
        self._invoice_amount_adjusted = invoice_amount_adjusted

    @property
    def invoice_amount_applied(self):
        """
        Gets the invoice_amount_applied of this InvoiceSummary.
        Invoice amount applied


        :return: The invoice_amount_applied of this InvoiceSummary.
        :rtype: float
        """
        return self._invoice_amount_applied

    @invoice_amount_applied.setter
    def invoice_amount_applied(self, invoice_amount_applied):
        """
        Sets the invoice_amount_applied of this InvoiceSummary.
        Invoice amount applied


        :param invoice_amount_applied: The invoice_amount_applied of this InvoiceSummary.
        :type: float
        """
        self._invoice_amount_applied = invoice_amount_applied

    @property
    def time_invoice_due(self):
        """
        Gets the time_invoice_due of this InvoiceSummary.
        Due date of invoice amount


        :return: The time_invoice_due of this InvoiceSummary.
        :rtype: datetime
        """
        return self._time_invoice_due

    @time_invoice_due.setter
    def time_invoice_due(self, time_invoice_due):
        """
        Sets the time_invoice_due of this InvoiceSummary.
        Due date of invoice amount


        :param time_invoice_due: The time_invoice_due of this InvoiceSummary.
        :type: datetime
        """
        self._time_invoice_due = time_invoice_due

    @property
    def is_payment_failed(self):
        """
        Gets the is_payment_failed of this InvoiceSummary.
        Is the last payment failed


        :return: The is_payment_failed of this InvoiceSummary.
        :rtype: bool
        """
        return self._is_payment_failed

    @is_payment_failed.setter
    def is_payment_failed(self, is_payment_failed):
        """
        Sets the is_payment_failed of this InvoiceSummary.
        Is the last payment failed


        :param is_payment_failed: The is_payment_failed of this InvoiceSummary.
        :type: bool
        """
        self._is_payment_failed = is_payment_failed

    @property
    def invoice_amount_in_dispute(self):
        """
        Gets the invoice_amount_in_dispute of this InvoiceSummary.
        Invoice amount in dispute


        :return: The invoice_amount_in_dispute of this InvoiceSummary.
        :rtype: float
        """
        return self._invoice_amount_in_dispute

    @invoice_amount_in_dispute.setter
    def invoice_amount_in_dispute(self, invoice_amount_in_dispute):
        """
        Sets the invoice_amount_in_dispute of this InvoiceSummary.
        Invoice amount in dispute


        :param invoice_amount_in_dispute: The invoice_amount_in_dispute of this InvoiceSummary.
        :type: float
        """
        self._invoice_amount_in_dispute = invoice_amount_in_dispute

    @property
    def invoice_ref_number(self):
        """
        Gets the invoice_ref_number of this InvoiceSummary.
        Invoice reference number


        :return: The invoice_ref_number of this InvoiceSummary.
        :rtype: str
        """
        return self._invoice_ref_number

    @invoice_ref_number.setter
    def invoice_ref_number(self, invoice_ref_number):
        """
        Sets the invoice_ref_number of this InvoiceSummary.
        Invoice reference number


        :param invoice_ref_number: The invoice_ref_number of this InvoiceSummary.
        :type: str
        """
        self._invoice_ref_number = invoice_ref_number

    @property
    def invoice_po_number(self):
        """
        Gets the invoice_po_number of this InvoiceSummary.
        Invoice PO number


        :return: The invoice_po_number of this InvoiceSummary.
        :rtype: str
        """
        return self._invoice_po_number

    @invoice_po_number.setter
    def invoice_po_number(self, invoice_po_number):
        """
        Sets the invoice_po_number of this InvoiceSummary.
        Invoice PO number


        :param invoice_po_number: The invoice_po_number of this InvoiceSummary.
        :type: str
        """
        self._invoice_po_number = invoice_po_number

    @property
    def time_invoice(self):
        """
        Gets the time_invoice of this InvoiceSummary.
        Date of invoice


        :return: The time_invoice of this InvoiceSummary.
        :rtype: datetime
        """
        return self._time_invoice

    @time_invoice.setter
    def time_invoice(self, time_invoice):
        """
        Sets the time_invoice of this InvoiceSummary.
        Date of invoice


        :param time_invoice: The time_invoice of this InvoiceSummary.
        :type: datetime
        """
        self._time_invoice = time_invoice

    @property
    def currency(self):
        """
        Gets the currency of this InvoiceSummary.

        :return: The currency of this InvoiceSummary.
        :rtype: oci.osp_gateway.models.Currency
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """
        Sets the currency of this InvoiceSummary.

        :param currency: The currency of this InvoiceSummary.
        :type: oci.osp_gateway.models.Currency
        """
        self._currency = currency

    @property
    def is_pdf_email_available(self):
        """
        Gets the is_pdf_email_available of this InvoiceSummary.
        Is emailing pdf allowed


        :return: The is_pdf_email_available of this InvoiceSummary.
        :rtype: bool
        """
        return self._is_pdf_email_available

    @is_pdf_email_available.setter
    def is_pdf_email_available(self, is_pdf_email_available):
        """
        Sets the is_pdf_email_available of this InvoiceSummary.
        Is emailing pdf allowed


        :param is_pdf_email_available: The is_pdf_email_available of this InvoiceSummary.
        :type: bool
        """
        self._is_pdf_email_available = is_pdf_email_available

    @property
    def is_display_view_pdf(self):
        """
        Gets the is_display_view_pdf of this InvoiceSummary.
        Is view access allowed


        :return: The is_display_view_pdf of this InvoiceSummary.
        :rtype: bool
        """
        return self._is_display_view_pdf

    @is_display_view_pdf.setter
    def is_display_view_pdf(self, is_display_view_pdf):
        """
        Sets the is_display_view_pdf of this InvoiceSummary.
        Is view access allowed


        :param is_display_view_pdf: The is_display_view_pdf of this InvoiceSummary.
        :type: bool
        """
        self._is_display_view_pdf = is_display_view_pdf

    @property
    def is_display_download_pdf(self):
        """
        Gets the is_display_download_pdf of this InvoiceSummary.
        Is pdf download access allowed


        :return: The is_display_download_pdf of this InvoiceSummary.
        :rtype: bool
        """
        return self._is_display_download_pdf

    @is_display_download_pdf.setter
    def is_display_download_pdf(self, is_display_download_pdf):
        """
        Sets the is_display_download_pdf of this InvoiceSummary.
        Is pdf download access allowed


        :param is_display_download_pdf: The is_display_download_pdf of this InvoiceSummary.
        :type: bool
        """
        self._is_display_download_pdf = is_display_download_pdf

    @property
    def last_payment_detail(self):
        """
        Gets the last_payment_detail of this InvoiceSummary.

        :return: The last_payment_detail of this InvoiceSummary.
        :rtype: oci.osp_gateway.models.PaymentDetail
        """
        return self._last_payment_detail

    @last_payment_detail.setter
    def last_payment_detail(self, last_payment_detail):
        """
        Sets the last_payment_detail of this InvoiceSummary.

        :param last_payment_detail: The last_payment_detail of this InvoiceSummary.
        :type: oci.osp_gateway.models.PaymentDetail
        """
        self._last_payment_detail = last_payment_detail

    @property
    def party_name(self):
        """
        Gets the party_name of this InvoiceSummary.
        Name of the bill to customer


        :return: The party_name of this InvoiceSummary.
        :rtype: str
        """
        return self._party_name

    @party_name.setter
    def party_name(self, party_name):
        """
        Sets the party_name of this InvoiceSummary.
        Name of the bill to customer


        :param party_name: The party_name of this InvoiceSummary.
        :type: str
        """
        self._party_name = party_name

    @property
    def subscription_ids(self):
        """
        Gets the subscription_ids of this InvoiceSummary.
        List of subscription identifiers


        :return: The subscription_ids of this InvoiceSummary.
        :rtype: list[str]
        """
        return self._subscription_ids

    @subscription_ids.setter
    def subscription_ids(self, subscription_ids):
        """
        Sets the subscription_ids of this InvoiceSummary.
        List of subscription identifiers


        :param subscription_ids: The subscription_ids of this InvoiceSummary.
        :type: list[str]
        """
        self._subscription_ids = subscription_ids

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .dvp_stack_details import DvpStackDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OracleRMStack(DvpStackDetails):
    """
    DVP details of Oracle RM stack.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new OracleRMStack object with values from keyword arguments. The default value of the :py:attr:`~oci.apm_synthetics.models.OracleRMStack.dvp_stack_type` attribute
        of this class is ``ORACLE_RM_STACK`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param dvp_stack_type:
            The value to assign to the dvp_stack_type property of this OracleRMStack.
            Allowed values for this property are: "ORACLE_RM_STACK"
        :type dvp_stack_type: str

        :param dvp_version:
            The value to assign to the dvp_version property of this OracleRMStack.
        :type dvp_version: str

        :param dvp_stack_id:
            The value to assign to the dvp_stack_id property of this OracleRMStack.
        :type dvp_stack_id: str

        :param dvp_stream_id:
            The value to assign to the dvp_stream_id property of this OracleRMStack.
        :type dvp_stream_id: str

        """
        self.swagger_types = {
            'dvp_stack_type': 'str',
            'dvp_version': 'str',
            'dvp_stack_id': 'str',
            'dvp_stream_id': 'str'
        }

        self.attribute_map = {
            'dvp_stack_type': 'dvpStackType',
            'dvp_version': 'dvpVersion',
            'dvp_stack_id': 'dvpStackId',
            'dvp_stream_id': 'dvpStreamId'
        }

        self._dvp_stack_type = None
        self._dvp_version = None
        self._dvp_stack_id = None
        self._dvp_stream_id = None
        self._dvp_stack_type = 'ORACLE_RM_STACK'

    @property
    def dvp_stack_id(self):
        """
        **[Required]** Gets the dvp_stack_id of this OracleRMStack.
        Stack `OCID`__ of DVP RM stack.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The dvp_stack_id of this OracleRMStack.
        :rtype: str
        """
        return self._dvp_stack_id

    @dvp_stack_id.setter
    def dvp_stack_id(self, dvp_stack_id):
        """
        Sets the dvp_stack_id of this OracleRMStack.
        Stack `OCID`__ of DVP RM stack.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param dvp_stack_id: The dvp_stack_id of this OracleRMStack.
        :type: str
        """
        self._dvp_stack_id = dvp_stack_id

    @property
    def dvp_stream_id(self):
        """
        **[Required]** Gets the dvp_stream_id of this OracleRMStack.
        Stream `OCID`__ of DVP RM stack.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The dvp_stream_id of this OracleRMStack.
        :rtype: str
        """
        return self._dvp_stream_id

    @dvp_stream_id.setter
    def dvp_stream_id(self, dvp_stream_id):
        """
        Sets the dvp_stream_id of this OracleRMStack.
        Stream `OCID`__ of DVP RM stack.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param dvp_stream_id: The dvp_stream_id of this OracleRMStack.
        :type: str
        """
        self._dvp_stream_id = dvp_stream_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDiscoveryJobDetails(object):
    """
    The request of DiscoveryJob details.
    """

    #: A constant which can be used with the discovery_type property of a CreateDiscoveryJobDetails.
    #: This constant has a value of "ADD"
    DISCOVERY_TYPE_ADD = "ADD"

    #: A constant which can be used with the discovery_type property of a CreateDiscoveryJobDetails.
    #: This constant has a value of "ADD_WITH_RETRY"
    DISCOVERY_TYPE_ADD_WITH_RETRY = "ADD_WITH_RETRY"

    #: A constant which can be used with the discovery_type property of a CreateDiscoveryJobDetails.
    #: This constant has a value of "REFRESH"
    DISCOVERY_TYPE_REFRESH = "REFRESH"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDiscoveryJobDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param discovery_type:
            The value to assign to the discovery_type property of this CreateDiscoveryJobDetails.
            Allowed values for this property are: "ADD", "ADD_WITH_RETRY", "REFRESH"
        :type discovery_type: str

        :param discovery_client:
            The value to assign to the discovery_client property of this CreateDiscoveryJobDetails.
        :type discovery_client: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateDiscoveryJobDetails.
        :type compartment_id: str

        :param discovery_details:
            The value to assign to the discovery_details property of this CreateDiscoveryJobDetails.
        :type discovery_details: oci.stack_monitoring.models.DiscoveryDetails

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateDiscoveryJobDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateDiscoveryJobDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'discovery_type': 'str',
            'discovery_client': 'str',
            'compartment_id': 'str',
            'discovery_details': 'DiscoveryDetails',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'discovery_type': 'discoveryType',
            'discovery_client': 'discoveryClient',
            'compartment_id': 'compartmentId',
            'discovery_details': 'discoveryDetails',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._discovery_type = None
        self._discovery_client = None
        self._compartment_id = None
        self._discovery_details = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def discovery_type(self):
        """
        Gets the discovery_type of this CreateDiscoveryJobDetails.
        Add option submits new discovery Job. Add with retry option to re-submit failed discovery job. Refresh option refreshes the existing discovered resources.

        Allowed values for this property are: "ADD", "ADD_WITH_RETRY", "REFRESH"


        :return: The discovery_type of this CreateDiscoveryJobDetails.
        :rtype: str
        """
        return self._discovery_type

    @discovery_type.setter
    def discovery_type(self, discovery_type):
        """
        Sets the discovery_type of this CreateDiscoveryJobDetails.
        Add option submits new discovery Job. Add with retry option to re-submit failed discovery job. Refresh option refreshes the existing discovered resources.


        :param discovery_type: The discovery_type of this CreateDiscoveryJobDetails.
        :type: str
        """
        allowed_values = ["ADD", "ADD_WITH_RETRY", "REFRESH"]
        if not value_allowed_none_or_none_sentinel(discovery_type, allowed_values):
            raise ValueError(
                "Invalid value for `discovery_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._discovery_type = discovery_type

    @property
    def discovery_client(self):
        """
        Gets the discovery_client of this CreateDiscoveryJobDetails.
        Client who submits discovery job.


        :return: The discovery_client of this CreateDiscoveryJobDetails.
        :rtype: str
        """
        return self._discovery_client

    @discovery_client.setter
    def discovery_client(self, discovery_client):
        """
        Sets the discovery_client of this CreateDiscoveryJobDetails.
        Client who submits discovery job.


        :param discovery_client: The discovery_client of this CreateDiscoveryJobDetails.
        :type: str
        """
        self._discovery_client = discovery_client

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateDiscoveryJobDetails.
        The OCID of Compartment


        :return: The compartment_id of this CreateDiscoveryJobDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateDiscoveryJobDetails.
        The OCID of Compartment


        :param compartment_id: The compartment_id of this CreateDiscoveryJobDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def discovery_details(self):
        """
        **[Required]** Gets the discovery_details of this CreateDiscoveryJobDetails.

        :return: The discovery_details of this CreateDiscoveryJobDetails.
        :rtype: oci.stack_monitoring.models.DiscoveryDetails
        """
        return self._discovery_details

    @discovery_details.setter
    def discovery_details(self, discovery_details):
        """
        Sets the discovery_details of this CreateDiscoveryJobDetails.

        :param discovery_details: The discovery_details of this CreateDiscoveryJobDetails.
        :type: oci.stack_monitoring.models.DiscoveryDetails
        """
        self._discovery_details = discovery_details

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateDiscoveryJobDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CreateDiscoveryJobDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateDiscoveryJobDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CreateDiscoveryJobDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateDiscoveryJobDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CreateDiscoveryJobDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateDiscoveryJobDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CreateDiscoveryJobDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AllowedPhaseOneParameters(object):
    """
    Allowed phase one parameters.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AllowedPhaseOneParameters object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param encryption_algorithms:
            The value to assign to the encryption_algorithms property of this AllowedPhaseOneParameters.
        :type encryption_algorithms: list[str]

        :param authentication_algorithms:
            The value to assign to the authentication_algorithms property of this AllowedPhaseOneParameters.
        :type authentication_algorithms: list[str]

        :param dh_groups:
            The value to assign to the dh_groups property of this AllowedPhaseOneParameters.
        :type dh_groups: list[str]

        """
        self.swagger_types = {
            'encryption_algorithms': 'list[str]',
            'authentication_algorithms': 'list[str]',
            'dh_groups': 'list[str]'
        }

        self.attribute_map = {
            'encryption_algorithms': 'encryptionAlgorithms',
            'authentication_algorithms': 'authenticationAlgorithms',
            'dh_groups': 'dhGroups'
        }

        self._encryption_algorithms = None
        self._authentication_algorithms = None
        self._dh_groups = None

    @property
    def encryption_algorithms(self):
        """
        Gets the encryption_algorithms of this AllowedPhaseOneParameters.
        Allowed phase one encryption algorithms.


        :return: The encryption_algorithms of this AllowedPhaseOneParameters.
        :rtype: list[str]
        """
        return self._encryption_algorithms

    @encryption_algorithms.setter
    def encryption_algorithms(self, encryption_algorithms):
        """
        Sets the encryption_algorithms of this AllowedPhaseOneParameters.
        Allowed phase one encryption algorithms.


        :param encryption_algorithms: The encryption_algorithms of this AllowedPhaseOneParameters.
        :type: list[str]
        """
        self._encryption_algorithms = encryption_algorithms

    @property
    def authentication_algorithms(self):
        """
        Gets the authentication_algorithms of this AllowedPhaseOneParameters.
        Allowed phase one authentication algorithms.


        :return: The authentication_algorithms of this AllowedPhaseOneParameters.
        :rtype: list[str]
        """
        return self._authentication_algorithms

    @authentication_algorithms.setter
    def authentication_algorithms(self, authentication_algorithms):
        """
        Sets the authentication_algorithms of this AllowedPhaseOneParameters.
        Allowed phase one authentication algorithms.


        :param authentication_algorithms: The authentication_algorithms of this AllowedPhaseOneParameters.
        :type: list[str]
        """
        self._authentication_algorithms = authentication_algorithms

    @property
    def dh_groups(self):
        """
        Gets the dh_groups of this AllowedPhaseOneParameters.
        Allowed phase one Diffie-Hellman groups.


        :return: The dh_groups of this AllowedPhaseOneParameters.
        :rtype: list[str]
        """
        return self._dh_groups

    @dh_groups.setter
    def dh_groups(self, dh_groups):
        """
        Sets the dh_groups of this AllowedPhaseOneParameters.
        Allowed phase one Diffie-Hellman groups.


        :param dh_groups: The dh_groups of this AllowedPhaseOneParameters.
        :type: list[str]
        """
        self._dh_groups = dh_groups

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .repository_ref_summary import RepositoryRefSummary
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RepositoryBranchSummary(RepositoryRefSummary):
    """
    Branch related information.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RepositoryBranchSummary object with values from keyword arguments. The default value of the :py:attr:`~oci.devops.models.RepositoryBranchSummary.ref_type` attribute
        of this class is ``BRANCH`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param ref_name:
            The value to assign to the ref_name property of this RepositoryBranchSummary.
        :type ref_name: str

        :param ref_type:
            The value to assign to the ref_type property of this RepositoryBranchSummary.
        :type ref_type: str

        :param full_ref_name:
            The value to assign to the full_ref_name property of this RepositoryBranchSummary.
        :type full_ref_name: str

        :param repository_id:
            The value to assign to the repository_id property of this RepositoryBranchSummary.
        :type repository_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this RepositoryBranchSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this RepositoryBranchSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param commit_id:
            The value to assign to the commit_id property of this RepositoryBranchSummary.
        :type commit_id: str

        """
        self.swagger_types = {
            'ref_name': 'str',
            'ref_type': 'str',
            'full_ref_name': 'str',
            'repository_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'commit_id': 'str'
        }

        self.attribute_map = {
            'ref_name': 'refName',
            'ref_type': 'refType',
            'full_ref_name': 'fullRefName',
            'repository_id': 'repositoryId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'commit_id': 'commitId'
        }

        self._ref_name = None
        self._ref_type = None
        self._full_ref_name = None
        self._repository_id = None
        self._freeform_tags = None
        self._defined_tags = None
        self._commit_id = None
        self._ref_type = 'BRANCH'

    @property
    def commit_id(self):
        """
        **[Required]** Gets the commit_id of this RepositoryBranchSummary.
        Commit ID pointed to by the new branch.


        :return: The commit_id of this RepositoryBranchSummary.
        :rtype: str
        """
        return self._commit_id

    @commit_id.setter
    def commit_id(self, commit_id):
        """
        Sets the commit_id of this RepositoryBranchSummary.
        Commit ID pointed to by the new branch.


        :param commit_id: The commit_id of this RepositoryBranchSummary.
        :type: str
        """
        self._commit_id = commit_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreatePrivateApplicationDetails(object):
    """
    The model for the parameters needed to create a private application.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreatePrivateApplicationDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreatePrivateApplicationDetails.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this CreatePrivateApplicationDetails.
        :type display_name: str

        :param short_description:
            The value to assign to the short_description property of this CreatePrivateApplicationDetails.
        :type short_description: str

        :param long_description:
            The value to assign to the long_description property of this CreatePrivateApplicationDetails.
        :type long_description: str

        :param logo_file_base64_encoded:
            The value to assign to the logo_file_base64_encoded property of this CreatePrivateApplicationDetails.
        :type logo_file_base64_encoded: str

        :param package_details:
            The value to assign to the package_details property of this CreatePrivateApplicationDetails.
        :type package_details: oci.service_catalog.models.CreatePrivateApplicationPackage

        :param defined_tags:
            The value to assign to the defined_tags property of this CreatePrivateApplicationDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreatePrivateApplicationDetails.
        :type freeform_tags: dict(str, str)

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'display_name': 'str',
            'short_description': 'str',
            'long_description': 'str',
            'logo_file_base64_encoded': 'str',
            'package_details': 'CreatePrivateApplicationPackage',
            'defined_tags': 'dict(str, dict(str, object))',
            'freeform_tags': 'dict(str, str)'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'short_description': 'shortDescription',
            'long_description': 'longDescription',
            'logo_file_base64_encoded': 'logoFileBase64Encoded',
            'package_details': 'packageDetails',
            'defined_tags': 'definedTags',
            'freeform_tags': 'freeformTags'
        }

        self._compartment_id = None
        self._display_name = None
        self._short_description = None
        self._long_description = None
        self._logo_file_base64_encoded = None
        self._package_details = None
        self._defined_tags = None
        self._freeform_tags = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreatePrivateApplicationDetails.
        The `OCID`__ of the compartment where you want to create the private application.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreatePrivateApplicationDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreatePrivateApplicationDetails.
        The `OCID`__ of the compartment where you want to create the private application.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreatePrivateApplicationDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreatePrivateApplicationDetails.
        The name of the private application.


        :return: The display_name of this CreatePrivateApplicationDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreatePrivateApplicationDetails.
        The name of the private application.


        :param display_name: The display_name of this CreatePrivateApplicationDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def short_description(self):
        """
        **[Required]** Gets the short_description of this CreatePrivateApplicationDetails.
        A short description of the private application.


        :return: The short_description of this CreatePrivateApplicationDetails.
        :rtype: str
        """
        return self._short_description

    @short_description.setter
    def short_description(self, short_description):
        """
        Sets the short_description of this CreatePrivateApplicationDetails.
        A short description of the private application.


        :param short_description: The short_description of this CreatePrivateApplicationDetails.
        :type: str
        """
        self._short_description = short_description

    @property
    def long_description(self):
        """
        Gets the long_description of this CreatePrivateApplicationDetails.
        A long description of the private application.


        :return: The long_description of this CreatePrivateApplicationDetails.
        :rtype: str
        """
        return self._long_description

    @long_description.setter
    def long_description(self, long_description):
        """
        Sets the long_description of this CreatePrivateApplicationDetails.
        A long description of the private application.


        :param long_description: The long_description of this CreatePrivateApplicationDetails.
        :type: str
        """
        self._long_description = long_description

    @property
    def logo_file_base64_encoded(self):
        """
        Gets the logo_file_base64_encoded of this CreatePrivateApplicationDetails.
        Base64-encoded logo to use as the private application icon.
        Template icon file requirements: PNG format, 50 KB maximum, 130 x 130 pixels.


        :return: The logo_file_base64_encoded of this CreatePrivateApplicationDetails.
        :rtype: str
        """
        return self._logo_file_base64_encoded

    @logo_file_base64_encoded.setter
    def logo_file_base64_encoded(self, logo_file_base64_encoded):
        """
        Sets the logo_file_base64_encoded of this CreatePrivateApplicationDetails.
        Base64-encoded logo to use as the private application icon.
        Template icon file requirements: PNG format, 50 KB maximum, 130 x 130 pixels.


        :param logo_file_base64_encoded: The logo_file_base64_encoded of this CreatePrivateApplicationDetails.
        :type: str
        """
        self._logo_file_base64_encoded = logo_file_base64_encoded

    @property
    def package_details(self):
        """
        **[Required]** Gets the package_details of this CreatePrivateApplicationDetails.

        :return: The package_details of this CreatePrivateApplicationDetails.
        :rtype: oci.service_catalog.models.CreatePrivateApplicationPackage
        """
        return self._package_details

    @package_details.setter
    def package_details(self, package_details):
        """
        Sets the package_details of this CreatePrivateApplicationDetails.

        :param package_details: The package_details of this CreatePrivateApplicationDetails.
        :type: oci.service_catalog.models.CreatePrivateApplicationPackage
        """
        self._package_details = package_details

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreatePrivateApplicationDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CreatePrivateApplicationDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreatePrivateApplicationDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CreatePrivateApplicationDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreatePrivateApplicationDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CreatePrivateApplicationDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreatePrivateApplicationDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CreatePrivateApplicationDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .abstract_call_attribute import AbstractCallAttribute
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BipCallAttribute(AbstractCallAttribute):
    """
    The call attributes impl
    """

    def __init__(self, **kwargs):
        """
        Initializes a new BipCallAttribute object with values from keyword arguments. The default value of the :py:attr:`~oci.data_connectivity.models.BipCallAttribute.model_type` attribute
        of this class is ``BIPCALLATTRIBUTE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this BipCallAttribute.
            Allowed values for this property are: "BIPCALLATTRIBUTE"
        :type model_type: str

        :param staging_bucket:
            The value to assign to the staging_bucket property of this BipCallAttribute.
        :type staging_bucket: oci.data_connectivity.models.Schema

        :param offset_parameter:
            The value to assign to the offset_parameter property of this BipCallAttribute.
        :type offset_parameter: str

        :param fetch_next_rows_parameter:
            The value to assign to the fetch_next_rows_parameter property of this BipCallAttribute.
        :type fetch_next_rows_parameter: str

        :param staging_data_asset:
            The value to assign to the staging_data_asset property of this BipCallAttribute.
        :type staging_data_asset: oci.data_connectivity.models.DataAsset

        :param staging_connection:
            The value to assign to the staging_connection property of this BipCallAttribute.
        :type staging_connection: oci.data_connectivity.models.Connection

        :param staging_prefix:
            The value to assign to the staging_prefix property of this BipCallAttribute.
        :type staging_prefix: str

        """
        self.swagger_types = {
            'model_type': 'str',
            'staging_bucket': 'Schema',
            'offset_parameter': 'str',
            'fetch_next_rows_parameter': 'str',
            'staging_data_asset': 'DataAsset',
            'staging_connection': 'Connection',
            'staging_prefix': 'str'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'staging_bucket': 'stagingBucket',
            'offset_parameter': 'offsetParameter',
            'fetch_next_rows_parameter': 'fetchNextRowsParameter',
            'staging_data_asset': 'stagingDataAsset',
            'staging_connection': 'stagingConnection',
            'staging_prefix': 'stagingPrefix'
        }

        self._model_type = None
        self._staging_bucket = None
        self._offset_parameter = None
        self._fetch_next_rows_parameter = None
        self._staging_data_asset = None
        self._staging_connection = None
        self._staging_prefix = None
        self._model_type = 'BIPCALLATTRIBUTE'

    @property
    def staging_bucket(self):
        """
        Gets the staging_bucket of this BipCallAttribute.

        :return: The staging_bucket of this BipCallAttribute.
        :rtype: oci.data_connectivity.models.Schema
        """
        return self._staging_bucket

    @staging_bucket.setter
    def staging_bucket(self, staging_bucket):
        """
        Sets the staging_bucket of this BipCallAttribute.

        :param staging_bucket: The staging_bucket of this BipCallAttribute.
        :type: oci.data_connectivity.models.Schema
        """
        self._staging_bucket = staging_bucket

    @property
    def offset_parameter(self):
        """
        Gets the offset_parameter of this BipCallAttribute.
        Parameter to set offset


        :return: The offset_parameter of this BipCallAttribute.
        :rtype: str
        """
        return self._offset_parameter

    @offset_parameter.setter
    def offset_parameter(self, offset_parameter):
        """
        Sets the offset_parameter of this BipCallAttribute.
        Parameter to set offset


        :param offset_parameter: The offset_parameter of this BipCallAttribute.
        :type: str
        """
        self._offset_parameter = offset_parameter

    @property
    def fetch_next_rows_parameter(self):
        """
        Gets the fetch_next_rows_parameter of this BipCallAttribute.
        Parameter to fetch next set of rows


        :return: The fetch_next_rows_parameter of this BipCallAttribute.
        :rtype: str
        """
        return self._fetch_next_rows_parameter

    @fetch_next_rows_parameter.setter
    def fetch_next_rows_parameter(self, fetch_next_rows_parameter):
        """
        Sets the fetch_next_rows_parameter of this BipCallAttribute.
        Parameter to fetch next set of rows


        :param fetch_next_rows_parameter: The fetch_next_rows_parameter of this BipCallAttribute.
        :type: str
        """
        self._fetch_next_rows_parameter = fetch_next_rows_parameter

    @property
    def staging_data_asset(self):
        """
        Gets the staging_data_asset of this BipCallAttribute.

        :return: The staging_data_asset of this BipCallAttribute.
        :rtype: oci.data_connectivity.models.DataAsset
        """
        return self._staging_data_asset

    @staging_data_asset.setter
    def staging_data_asset(self, staging_data_asset):
        """
        Sets the staging_data_asset of this BipCallAttribute.

        :param staging_data_asset: The staging_data_asset of this BipCallAttribute.
        :type: oci.data_connectivity.models.DataAsset
        """
        self._staging_data_asset = staging_data_asset

    @property
    def staging_connection(self):
        """
        Gets the staging_connection of this BipCallAttribute.

        :return: The staging_connection of this BipCallAttribute.
        :rtype: oci.data_connectivity.models.Connection
        """
        return self._staging_connection

    @staging_connection.setter
    def staging_connection(self, staging_connection):
        """
        Sets the staging_connection of this BipCallAttribute.

        :param staging_connection: The staging_connection of this BipCallAttribute.
        :type: oci.data_connectivity.models.Connection
        """
        self._staging_connection = staging_connection

    @property
    def staging_prefix(self):
        """
        Gets the staging_prefix of this BipCallAttribute.
        Prefix for the staging DataAsset


        :return: The staging_prefix of this BipCallAttribute.
        :rtype: str
        """
        return self._staging_prefix

    @staging_prefix.setter
    def staging_prefix(self, staging_prefix):
        """
        Sets the staging_prefix of this BipCallAttribute.
        Prefix for the staging DataAsset


        :param staging_prefix: The staging_prefix of this BipCallAttribute.
        :type: str
        """
        self._staging_prefix = staging_prefix

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .abstract_frequency_details import AbstractFrequencyDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CustomFrequencyDetails(AbstractFrequencyDetails):
    """
    Frequency details model to set cron-based frequency
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CustomFrequencyDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.CustomFrequencyDetails.model_type` attribute
        of this class is ``CUSTOM`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this CustomFrequencyDetails.
            Allowed values for this property are: "HOURLY", "DAILY", "MONTHLY", "WEEKLY", "MONTHLY_RULE", "CUSTOM"
        :type model_type: str

        :param frequency:
            The value to assign to the frequency property of this CustomFrequencyDetails.
            Allowed values for this property are: "HOURLY", "DAILY", "MONTHLY", "WEEKLY", "CUSTOM"
        :type frequency: str

        :param custom_expression:
            The value to assign to the custom_expression property of this CustomFrequencyDetails.
        :type custom_expression: str

        """
        self.swagger_types = {
            'model_type': 'str',
            'frequency': 'str',
            'custom_expression': 'str'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'frequency': 'frequency',
            'custom_expression': 'customExpression'
        }

        self._model_type = None
        self._frequency = None
        self._custom_expression = None
        self._model_type = 'CUSTOM'

    @property
    def custom_expression(self):
        """
        Gets the custom_expression of this CustomFrequencyDetails.
        This holds the complete cron expression for this schedule, for example, 10 0/5 * * * ? that fires every 5 minutes, at 10 seconds after the minute (i.e. 10:00:10 am, 10:05:10 am, etc.)


        :return: The custom_expression of this CustomFrequencyDetails.
        :rtype: str
        """
        return self._custom_expression

    @custom_expression.setter
    def custom_expression(self, custom_expression):
        """
        Sets the custom_expression of this CustomFrequencyDetails.
        This holds the complete cron expression for this schedule, for example, 10 0/5 * * * ? that fires every 5 minutes, at 10 seconds after the minute (i.e. 10:00:10 am, 10:05:10 am, etc.)


        :param custom_expression: The custom_expression of this CustomFrequencyDetails.
        :type: str
        """
        self._custom_expression = custom_expression

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UnprocessedDataBucket(object):
    """
    Configuration details of the bucket that stores unprocessed payloads.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UnprocessedDataBucket object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param namespace:
            The value to assign to the namespace property of this UnprocessedDataBucket.
        :type namespace: str

        :param bucket_name:
            The value to assign to the bucket_name property of this UnprocessedDataBucket.
        :type bucket_name: str

        :param is_enabled:
            The value to assign to the is_enabled property of this UnprocessedDataBucket.
        :type is_enabled: bool

        :param time_created:
            The value to assign to the time_created property of this UnprocessedDataBucket.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this UnprocessedDataBucket.
        :type time_updated: datetime

        """
        self.swagger_types = {
            'namespace': 'str',
            'bucket_name': 'str',
            'is_enabled': 'bool',
            'time_created': 'datetime',
            'time_updated': 'datetime'
        }

        self.attribute_map = {
            'namespace': 'namespace',
            'bucket_name': 'bucketName',
            'is_enabled': 'isEnabled',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated'
        }

        self._namespace = None
        self._bucket_name = None
        self._is_enabled = None
        self._time_created = None
        self._time_updated = None

    @property
    def namespace(self):
        """
        **[Required]** Gets the namespace of this UnprocessedDataBucket.
        Object Storage namespace.


        :return: The namespace of this UnprocessedDataBucket.
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """
        Sets the namespace of this UnprocessedDataBucket.
        Object Storage namespace.


        :param namespace: The namespace of this UnprocessedDataBucket.
        :type: str
        """
        self._namespace = namespace

    @property
    def bucket_name(self):
        """
        **[Required]** Gets the bucket_name of this UnprocessedDataBucket.
        Name of the Object Storage bucket.


        :return: The bucket_name of this UnprocessedDataBucket.
        :rtype: str
        """
        return self._bucket_name

    @bucket_name.setter
    def bucket_name(self, bucket_name):
        """
        Sets the bucket_name of this UnprocessedDataBucket.
        Name of the Object Storage bucket.


        :param bucket_name: The bucket_name of this UnprocessedDataBucket.
        :type: str
        """
        self._bucket_name = bucket_name

    @property
    def is_enabled(self):
        """
        Gets the is_enabled of this UnprocessedDataBucket.
        Flag that specifies if this configuration is enabled or not.


        :return: The is_enabled of this UnprocessedDataBucket.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this UnprocessedDataBucket.
        Flag that specifies if this configuration is enabled or not.


        :param is_enabled: The is_enabled of this UnprocessedDataBucket.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def time_created(self):
        """
        Gets the time_created of this UnprocessedDataBucket.
        The time when this record is created. An RFC3339 formatted datetime string.


        :return: The time_created of this UnprocessedDataBucket.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this UnprocessedDataBucket.
        The time when this record is created. An RFC3339 formatted datetime string.


        :param time_created: The time_created of this UnprocessedDataBucket.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this UnprocessedDataBucket.
        The latest time when this record is updated. An RFC3339 formatted datetime string.


        :return: The time_updated of this UnprocessedDataBucket.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this UnprocessedDataBucket.
        The latest time when this record is updated. An RFC3339 formatted datetime string.


        :param time_updated: The time_updated of this UnprocessedDataBucket.
        :type: datetime
        """
        self._time_updated = time_updated

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
